@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_groups.pl 5651 2006-09-05 15:02:38Z yeupou $
+# $Id: sv_groups.pl 6513 2009-10-14 22:09:00Z esr $
 #
 #  Copyright 2001-2006 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
 #                          Mathieu Roy <yeupou--gnu.org> 
@@ -27,7 +27,7 @@
 ## This script should be used via a cronjob to update the system
 ## by reading the database about groups.
 ##
-## It will add create/update a group for each group. 
+## It will create/update a group for each group. 
 ## It will also create a download area, a web area, and a cvs repository 
 ## if in the database the fields dir_cvs dir_homepage and dir_download 
 ## contains the string %PROJECT
@@ -381,6 +381,8 @@ foreach my $group (@db_groups) {
 		    $madesomething .= SvnMakeArea($name,$dir_cvs,$is_public);
 		} elsif ($dir_type_cvs eq "svnattic") {
 		    $madesomething .= SvnMakeAreaAttic($name,$dir_svn,$is_public); 
+		} elsif ($dir_type_cvs eq "svnatticwebsite") {
+		    $madesomething .= SvnMakeAreaAtticWebsite($name,$dir_svn,$is_public); 
 		}
 	    }
 	    
@@ -400,8 +402,10 @@ foreach my $group (@db_groups) {
 		    $madesomething .= WebCvsMakeAreaSavannahNonGNU($name,$dir_homepage,$is_public);
 		} elsif ($dir_type_homepage eq "basicsvn") {
 		    $madesomething .= SvnMakeArea($name,$dir_homepage,$is_public);
-		}   elsif ($dir_type_homepage eq "svnattic") {
+		} elsif ($dir_type_homepage eq "svnattic") {
 		    $madesomething .= SvnMakeAreaAttic($name,$dir_svn,$is_public); 
+		} elsif ($dir_type_homepage eq "svnatticwebsite") {
+		    $madesomething .= SvnMakeAreaAtticWebsite($name,$dir_svn,$is_public); 
 		} 
 	    }
 	    
@@ -459,6 +463,10 @@ foreach my $group (@db_groups) {
 		    $madesomething .= SvnMakeArea($name,$dir_svn,$is_public);
 		} elsif ($dir_type_svn eq "svnattic") {
 		    $madesomething .= SvnMakeAreaAttic($name,$dir_svn,$is_public);
+		} elsif ($dir_type_svn eq "svnugent") {
+		    $madesomething .= SvnMakeAreaUgent($name,$dir_svn,$is_public); 
+		} elsif ($dir_type_svn eq "svnatticwebsite") {
+		    $madesomething .= SvnMakeAreaAtticWebsite($name,$dir_svn,$is_public); 
 		}
 	    }
 	}
