@@ -2,11 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: 404.php 5181 2005-12-01 13:31:07Z yeupou $
+# $Id: 404.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
 
 
 require "./include/pre.php";
-require_directory("search");
+register_globals_off();
 
 site_header(array('title'=>_("Requested Page not Found (Error 404)")));
 
