@@ -2,10 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: login.php 5890 2006-09-20 16:50:07Z yeupou $
+# $Id: login.php 6510 2008-01-05 16:33:35Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -32,6 +31,19 @@ require '../include/account.php';
 
 register_globals_off();
 
+# Block here potential robots
+# 2006-12-04, yeupou: allows them to login, so they can post on trackers of
+# their projects. This is a compromise between the need to avoid spam by all
+# means and the fact that we still want to allow to work people in obvious
+# legit cases even if they are blacklisted.
+# They wont be able to use savane normally but only to post on the project
+# they are member of. The way to go for them is to ask their IP to be delisted,
+# not from us to maintain another list of exceptions. If they cant, it is sad*
+# but we cannot encourage this because it would defeat the whole purpose of
+# DNSbl, while DNSbl seems to be the only truly effective way to get rid of
+# spams.
+#dnsbl_check();
+
 # Logged users have no business here
 if (user_isloggedin())
 { session_redirect($GLOBALS['sys_home']."my/"); }
@@ -131,7 +143,7 @@ if (sane_all("login"))
                 }
               else
                 {
-	         header ("Location: ".$http."://".$GLOBALS['sys_brother_domain'].$uri);
+	         header ("Location: ".$http."://".$GLOBALS['sys_brother_domain'].htmlspecialchars($uri));
                 }
 	      exit;
 	    }
@@ -146,7 +158,7 @@ if (sane_all("login"))
            }
           else
            {
-	      header ("Location: ".$http."://".$GLOBALS['sys_default_domain'].$uri);
+	      header ("Location: ".$http."://".$GLOBALS['sys_default_domain'].htmlspecialchars($uri));
            }
 	  exit;
 	}
@@ -203,7 +215,7 @@ print '<input type="hidden" name="uri" value="'.$uri.'" />';
 # so they dont mess with the normal order when you press TAB on the keyboard
 # (login -> password -> post)
 print '<p><span class="preinput">'._("Login Name:").'</span><br />&nbsp;&nbsp;';
-print '<input type="text" name="form_loginname" value="'.$form_loginname.'" tabindex="1" /> <a class="smaller" href="register.php" tabindex="2">['._("No account yet?").']</a></p>';
+print '<input type="text" name="form_loginname" value="'.htmlspecialchars($form_loginname).'" tabindex="1" /> <a class="smaller" href="register.php" tabindex="2">['._("No account yet?").']</a></p>';
 
 print '<p><span class="preinput">'._("Password:").'</span><br />&nbsp;&nbsp;';
 print '<input type="password" name="form_pw" tabindex="1" /> <a class="smaller" href="lostpw.php" tabindex="2">['._("Lost your password?").']</a></p>';
