@@ -2,10 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: lostpw-confirm.php 5788 2006-09-13 15:59:38Z yeupou $
+# $Id: lostpw-confirm.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Joxean Koret <joxeankoret--yahoo.es>
@@ -26,11 +25,16 @@
 
 require "../include/pre.php";
 
+register_globals_off();
+
 # Logged users have no business here
 if (user_isloggedin())
 { session_redirect($GLOBALS['sys_home']."my/"); }
 
-register_globals_off();
+# Block here potential robots
+dnsbl_check();
+# Block banned IP
+spam_bancheck();
 
 $form_loginname = sane_post("form_loginname");
 
