@@ -2,14 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pending.php 5788 2006-09-13 15:59:38Z yeupou $
+# $Id: pending.php 6431 2006-11-22 10:14:55Z yeupou $
 #
+#  Copyright 1999-2000 (c) The SourceForge Crew
 #
-#
-# Copyright 1999-2000 (c) The SourceForge Crew
-#
-#
-#  Copyright (C) 2000, 2001, 2002 Free Software Foundation
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,12 +21,12 @@
 # You should have received a copy of the GNU General Public License
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-#
-#
-#
-#
+
 
 require "../include/pre.php";
+register_globals_off();
+
+$form_user = sane_all("form_user");
 
 # Logged users have no business here
 if (user_isloggedin())
