@@ -2,10 +2,9 @@
 # This file is part of the Savane project
 # <http:#gna.org/projects/savane/>
 #
-# $Id: verify.php 5802 2006-09-14 12:40:09Z yeupou $
+# $Id: verify.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
@@ -28,6 +27,11 @@ require "../include/pre.php";
 
 register_globals_off();
 
+# Block here potential robots
+dnsbl_check();
+# Block banned IP
+spam_bancheck();
+
 # Logged users have no business here
 if (user_isloggedin())
 { session_redirect($GLOBALS['sys_home']."my/"); }
@@ -41,7 +45,7 @@ if (sane_post("update"))
    
   # first check just confirmation hash
   $res = db_query('SELECT confirm_hash,status FROM user WHERE '
-		  .'user_name="'.$form_loginname.'"');
+		  .'user_name="'.$form_loginname.'" and status<>"SQD"');
 
   if (db_numrows($res) < 1) 
     {
