@@ -107,25 +107,29 @@ function context_guess_from_url ($page, $dontset=false)
   # Same with site administration part  
   if ($context == "siteadmin")
   {
-      if ($page_basename == "group_type.php")
+      if ($page_basename == "group_type.php" || 
+	  $page_basename == "retestconfig.php")
 	{
-	  $subcontext = "grouptype";
+	  $subcontext = "configure";
 	  return context_set($context, $subcontext, $dontset);
 	}
-      if ($page_basename == "grouplist.php")
+      if ($page_basename == "grouplist.php" ||
+	  $page_basename == "groupedit.php" ||
+	  $page_basename == "userlist.php" ||
+	  $page_basename == "usergroup.php")
 	{
-	  $subcontext = "groupedit";
+	  $subcontext = "manage";
 	  return context_set($context, $subcontext, $dontset);
 	}
-      if ($page_basename == "groupedit.php")
+      if ($page_basename == "spamlist.php" ||
+	  $page_basename == "lastlogins.php")
 	{
-	  $subcontext = "groupedit";
+	  $subcontext = "monitor";
 	  return context_set($context, $subcontext, $dontset);
 	}
-      if ($page_basename == "userlist.php")
+      if (sane_isset("func"))
 	{
-	  $subcontext = "useredit";
-	  return context_set($context, $subcontext, $dontset);
+	  $subcontext = sane_all("func");
 	}
       return context_set($context, $subcontext, $dontset);
     }
