@@ -2,13 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: features_boxes.php 6015 2006-09-29 15:18:56Z yeupou $
+# $Id: features_boxes.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2000-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -82,9 +80,13 @@ function show_features_boxes()
 
   while ($eachtype = db_fetch_array($result))
     {
+      $groupdata = show_newest_projects($eachtype['type_id'], $limit);
+      if (!$groupdata)
+	{ continue; }
+      
       $return .= "<br />\n";
       $return .= $HTML->box_top(sprintf(_("Newest %s Projects"),$eachtype['name']),'',1);
-      $return .= show_newest_projects($group_type=$eachtype['type_id'], $limit);
+      $return .= $groupdata;
       global $j;
       $return .= '<div class="'.utils_get_alt_row_color($j).'"><span class="smaller"><a href="'.$GLOBALS['sys_home'].'search/?type_of_search=soft&amp;words=%%%&amp;type='.$eachtype['type_id'].'">[';
       $return .= sprintf( _("all %s projects"),$eachtype['name'] ) ;
@@ -125,10 +127,16 @@ function show_newest_projects($group_type, $limit)
 {
   global $j;
 
+  # Shows only projects that were added in the last trimester
+  $since = mktime(0,0,0,(date("m")-2));
+
   $sql =	"SELECT group_id,unix_group_name,group_name,register_time FROM groups " .
-     "WHERE is_public=1 AND status='A' AND type=$group_type " .
+     "WHERE is_public=1 AND status='A' AND type=$group_type AND register_time>='$since' " .
      "ORDER BY register_time DESC LIMIT $limit";
-  $res_newproj = db_query( $sql );
+  $res_newproj = db_query($sql);
+  if (!db_numrows($res_newproj))
+    { return false; }
+
   $sql_type = "SELECT type_id,base_host FROM group_type WHERE type_id=$group_type";
   $res_newproj_type = db_query($sql_type);
   $row_newproj_type = db_fetch_array($res_newproj_type);
@@ -136,24 +144,14 @@ function show_newest_projects($group_type, $limit)
     {
       $base_url = 'http'.(session_issecure()?'s':'').'://'.$row_newproj_type['base_host'];
     }
-
-  if (!$res_newproj || db_numrows($res_newproj) < 1)
+  
+  while ($row_newproj = db_fetch_array($res_newproj))
     {
-      return db_error();
-    }
-  else
-    {
-      while ( $row_newproj = db_fetch_array($res_newproj) )
+      if ($row_newproj['register_time'])
 	{
-	  if ( $row_newproj['register_time'] )
-	    {
-	      # It would be best to have only Month + Day, but php locale
-	      # implementations cant do that, apparently. Feel free to
-	      # improve.
-	      $return .= '<div class="'.utils_get_alt_row_color($j).'"><span class="smaller">&nbsp;&nbsp;- <a href="'.$base_url.$GLOBALS['sys_home']."projects/$row_newproj[unix_group_name]/\">"
-		 . $row_newproj[group_name].'</a>, '.format_date('minimal',$row_newproj['register_time']).'</span></div>';
-	      $j++;
-	    }
+	  $return .= '<div class="'.utils_get_alt_row_color($j).'"><span class="smaller">&nbsp;&nbsp;- <a href="'.$base_url.$GLOBALS['sys_home']."projects/$row_newproj[unix_group_name]/\">"
+	    . $row_newproj[group_name].'</a>, '.format_date('minimal',$row_newproj['register_time']).'</span></div>';
+	  $j++;
 	}
     }
   return $return;
