@@ -2,13 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php 5927 2006-09-21 16:43:33Z yeupou $
+# $Id: html.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Paul Pogonyshev <pogonyshev--gmx.net>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -119,6 +117,95 @@ EOF;
   return $ret;
 }
 
+# Function to create a an area in the page that can be hidden or shown 
+# in one click with a javascript
+# Per policy, this must work with a browser that does not support at all 
+# javascript
+# This is useful on item pages because we have some info that is not
+# essential to be shown (like CC list etc), but still very nice be able to
+# access easily
+function html_hidsubpart_header ($uniqueid, $title, $deployed=false)
+{
+  global $is_deployed;
+
+  # Try to find a deployed value that match the unique id
+  # If found, override the deployed setting (the deployed setting should be
+  # used to set a default behavior, but if in the case we explicitely 
+  # use an array to determine what is deployed, this matters more)
+  if (is_array($is_deployed) && 
+      array_key_exists($uniqueid, $is_deployed))
+    {
+      $deployed = $is_deployed[$uniqueid];
+    }
+
+  $script_hide = <<<EOF
+document.getElementById('hidsubpartcontent$uniqueid').style.display='none';   document.getElementById('hidsubpartlinkhide$uniqueid').style.display='none';   document.getElementById('hidsubpartlinkshow$uniqueid').style.display='block';
+EOF;
+  $script_show = <<<EOF
+document.getElementById('hidsubpartcontent$uniqueid').style.display='inline'; document.getElementById('hidsubpartlinkhide$uniqueid').style.display='block'; document.getElementById('hidsubpartlinkshow$uniqueid').style.display='none';
+EOF;
+
+  # put the #uniqueid at the begin because
+  # several browsers cant cope when
+  # there are several times the same
+  # anchor in a page
+  $ret .= '
+  <h3><a name="'.$uniqueid.'"></a>
+  <script type="text/javascript">';
+
+    if (!$deployed)
+    {
+      $ret .= '
+    document.write(\'<a onclick="'.addslashes($script_hide).'" id="hidsubpartlinkhide'.$uniqueid.'" style="display: none" href="#'.$uniqueid.'"><span class="minusorplus">(-)</span> '.htmlspecialchars($title, ENT_QUOTES).'</a>\');
+    document.write(\'<a onclick="'.addslashes($script_show).'" id="hidsubpartlinkshow'.$uniqueid.'" style="display: block" href="#'.$uniqueid.'"><span class="minusorplus">(+)</span> '.htmlspecialchars($title, ENT_QUOTES).'</a>\');';
+    }
+  else
+    {
+      $ret .= '
+    document.write(\'<a onclick="'.addslashes($script_hide).'" id="hidsubpartlinkhide'.$uniqueid.'" style="display: block" href="#'.$uniqueid.'"><span class="minusorplus">(-)</span> '.htmlspecialchars($title, ENT_QUOTES).'</a>\');
+    document.write(\'<a onclick="'.addslashes($script_show).'" id="hidsubpartlinkshow'.$uniqueid.'" style="display: none" href="#'.$uniqueid.'"><span class="minusorplus">(+)</span> '.htmlspecialchars($title, ENT_QUOTES).'</a>\');';
+
+    }
+    $ret .= '
+  </script>
+  <noscript>
+    <a id="hidsubpartlinkshow'.$uniqueid.'" href="#'.$uniqueid.'">'.$title.'</a>
+  </noscript>
+  </h3>';
+
+    if (!$deployed)
+      {
+	$ret .= '
+<script type="text/javascript">
+  document.write(\'<span id="hidsubpartcontent'.$uniqueid.'" style="display: none">\');
+</script>
+<noscript>
+  <span id="hidsubpartcontent'.$uniqueid.'">
+</noscript>
+';
+      }
+    else
+      {
+	$ret .= '
+<span id="hidsubpartcontent'.$uniqueid.'">
+';
+      }
+
+    return $ret;
+}
+
+
+function html_hidsubpart_footer ()
+{
+  return '
+</span><!-- closing hidsubpart -->
+';
+
+}
+
+
+
+
 
 function html_splitpage ($how)
 {
@@ -140,17 +227,22 @@ function html_splitpage ($how)
 }
 
 
-function html_nextprev ($search_url, $rows, $rows_returned)
+function html_nextprev ($search_url, $rows, $rows_returned, $varprefix=false)
 {
   global $offset, $max_rows;
 
+  if (!$varprefix)
+    { unset($varprefix); }
+  else
+    { $varprefix .= "_"; }
+
   if (($rows_returned > $rows) || ($offset != 0))
     {
       print "\n<br /><h5 class=\"nextprev\">\n";
 
       if ($offset != 0)
 	{
-	  print '<a href="'.$search_url.'&amp;offset='.($offset-$rows).'&amp;max_rows='.$max_rows.'#results">';
+	  print '<a href="'.$search_url.'&amp;'.$varprefix.'offset='.($offset-$rows).'&amp;'.$varprefix.'max_rows='.$max_rows.'#'.$varprefix.'results">';
 	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a>';
 
 	}
@@ -163,7 +255,7 @@ function html_nextprev ($search_url, $rows, $rows_returned)
 
       if ($rows_returned > $rows)
 	{
-	  print '<a href="'.$search_url.'&amp;offset='.($offset+$rows).'&amp;max_rows='.$max_rows.'#results">';
+	  print '<a href="'.$search_url.'&amp;'.$varprefix.'offset='.($offset+$rows).'&amp;'.$varprefix.'max_rows='.$max_rows.'#'.$varprefix.'results">';
 	  print _("Next Results").' <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'" /></a>';
 	}
       else
@@ -185,21 +277,16 @@ function html_anchor ($content, $name)
 # Print out the feedback
 function html_feedback_top()
 {
-  # By default, escape the html special chars, unless feedback_html was
-  # set in the code to allow an htmlized feedback (that should happen on rare
-  # occasions)
-  if (!$GLOBALS[feedback_html])
-    {
-      $GLOBALS[feedback] = htmlspecialchars($GLOBALS[feedback]);
-      $GLOBALS[ffeedback] = htmlspecialchars($GLOBALS[ffeedback]);
-    }
+  # Escape the html special chars, active markup
+  $GLOBALS[feedback] = markup_basic(htmlspecialchars($GLOBALS[feedback]));
+  $GLOBALS[ffeedback] = markup_basic(htmlspecialchars($GLOBALS[ffeedback]));
 
   $script_hide = 'onclick="document.getElementById(\'feedback\').style.visibility=\'hidden\'; document.getElementById(\'feedbackback\').style.visibility=\'visible\';"';
   $script_show = 'onclick="document.getElementById(\'feedback\').style.visibility=\'visible\'; document.getElementById(\'feedbackback\').style.visibility=\'hidden\';"';
 
   # With MSIE  the feedback will be be 
   # in relative position, so the hiding link will not make sense
-  if (strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") && !$_GET["printer"])
+  if (is_broken_msie() && !$_GET["printer"])
     { unset($script_hide); }
   # Users can choose the same behavior, disallowing the fixed positionning
   # of the feedback (less convenient as the feedback gets easily hidden,
@@ -321,7 +408,7 @@ function html_build_list_table_top ($title_arr,$links_arr=false,$table=true)
       for ($i=0; $i<$count; $i++)
 	{
 	  $return .= '
-			<td class="boxtitle"><a class="sortbutton" href="'.$links_arr[$i].'">'.$title_arr[$i].'</a></td>';
+			<th class="boxtitle"><a class="sortbutton" href="'.$links_arr[$i].'">'.$title_arr[$i].'</a></th>';
 	}
     }
   else
@@ -329,7 +416,7 @@ function html_build_list_table_top ($title_arr,$links_arr=false,$table=true)
       for ($i=0; $i<$count; $i++)
 	{
 	  $return .= '
-			<td class="boxtitle">'.$title_arr[$i].'</td>';
+			<th class="boxtitle">'.$title_arr[$i].'</th>';
 	}
     }
   return $return.'</tr>';
@@ -746,6 +833,7 @@ function html_select_typedir_box ($input_name, $current_value)
         <option value="basicsvn"'.(($current_value == "basicsvn")?" selected=\"selected\"":"").'>'._("Basic Subversion Directory").'</option>
         <option value="cvsattic"'.(($current_value == "cvsattic")?" selected=\"selected\"":"").'>'._("Cvs Attic/Gna").'</option>
         <option value="svnattic"'.(($current_value == "svnattic")?" selected=\"selected\"":"").'>'._("Subversion Attic/Gna").'</option>
+        <option value="svnatticwebsite"'.(($current_value == "svnatticwebsite")?" selected=\"selected\"":"").'>'._("Subversion Subdirectory Attic/Gna").'</option>
         <option value="savannah-gnu"'.(($current_value == "savannah-gnu")?" selected=\"selected\"":"").'>'._("Savannah GNU").'</option>
         <option value="savannah-nongnu"'.(($current_value == "savannah-nongnu")?" selected=\"selected\"":"").'>'._("Savannah non-GNU").'</option>
       </select> [BACKEND SPECIFIC]
