@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 6021 2006-10-02 07:41:42Z yeupou $
+# $Id: general.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -45,8 +45,6 @@ Output:
 
 */
 
-  global $PHP_SELF;
-
   # Determine if we should hide or not
   $hide = my_is_hidden($role, $group_id);
 
@@ -63,11 +61,11 @@ Output:
   # Determine the relevant content (title with a + or a -)
   if ($hide)
     {
-      $hide_url= '<a name="'.$role.$group_id.'" href="'.$PHP_SELF.'?hide_'.$role.'=0&amp;hide_group_id='.$group_id.'#'.$role.$group_id.'"><span class="minusorplus">(+)</span>'.$link.'</a>';
+      $hide_url= '<a name="'.$role.$group_id.'" href="'.$_SERVER['PHP_SELF'].'?hide_'.$role.'=0&amp;hide_group_id='.$group_id.'#'.$role.$group_id.'"><span class="minusorplus">(+)</span>'.$link.'</a>';
     }
   else
     {
-      $hide_url= '<a name="'.$role.$group_id.'" href="'.$PHP_SELF.'?hide_'.$role.'=1&amp;hide_group_id='.$group_id.'#'.$role.$group_id.'"><span class="minusorplus">(-)</span>'.$link.'</a>';
+      $hide_url= '<a name="'.$role.$group_id.'" href="'.$_SERVER['PHP_SELF'].'?hide_'.$role.'=1&amp;hide_group_id='.$group_id.'#'.$role.$group_id.'"><span class="minusorplus">(-)</span>'.$link.'</a>';
     }
 
   # Return everything
@@ -136,7 +134,7 @@ function my_item_count($total, $new)
 # doing hundred of time the same SQL requests.
 # Indeed, it is safe only as register_globals_off() is used on my/ pages
 # and since it is reinitialized at the begin of these pages.
-function my_item_list ($role="assignee", $threshold="5", $status="open", $uid=0, $condensed=0) {
+function my_item_list ($role="assignee", $threshold="5", $openclosed="open", $uid=0, $condensed=0) {
   global $item_data, $group_data, $items_per_groups, $maybe_missed_rows;
   $items_per_groups = array();
   
@@ -168,7 +166,7 @@ function my_item_list ($role="assignee", $threshold="5", $status="open", $uid=0,
 	  unset($sql);
 
 	  # Create the SQL request
-	  $sql = my_item_list_buildsql($currenttracker, $currentrole, $threshold, $status, $uid);
+	  $sql = my_item_list_buildsql($currenttracker, $currentrole, $threshold, $openclosed, $uid);
 
 	  # Ignores if not able to produce a SQL (maybe because the user
 	  # have no relevant rights, whatever)
@@ -182,19 +180,19 @@ function my_item_list ($role="assignee", $threshold="5", $status="open", $uid=0,
 
     }
   
-  my_item_list_print($role, $condensed);
+  my_item_list_print($role, $openclosed, $condensed);
 }
 
 
 # Build sql request depending on what we are looking for
-function my_item_list_buildsql ($tracker, $role="assignee", $threshold="5", $status="open", $uid=0) {
-  global $item_data, $group_data, $sql_limit, $usergroups, $usergroups_groupid, $items_per_groups;
+function my_item_list_buildsql ($tracker, $role="assignee", $threshold="5", $openclosed="open", $uid=false) {
+  global $item_data, $group_data, $sql_limit, $usergroups, $usergroups_groupid, $items_per_groups, $usersquads;
 
   # status: 1 = open, 3 = closed
-  if ($status == "open") 
-    { $status = 1; }
-  if ($status == "closed") 
-    { $status = 3; }
+  if ($openclosed == "open") 
+    { $openclosed = 1; }
+  if ($openclosed == "closed") 
+    { $openclosed = 3; }
 
 
   # Max items: defines to 50 by default
@@ -216,7 +214,7 @@ function my_item_list_buildsql ($tracker, $role="assignee", $threshold="5", $sta
       $showprivate = ' AND privacy<>2 ';
     }
 
-
+  
   # Get a timestamp to get new items (15 days)
   $new_date_limit = mktime(date("H"),
 			   date("i"),
@@ -234,11 +232,21 @@ function my_item_list_buildsql ($tracker, $role="assignee", $threshold="5", $sta
       $select = 'SELECT '.$tracker.'.bug_id,'.$tracker.'.date,'.$tracker.'.priority,'.$tracker.'.resolution_id,'.$tracker.'.summary,groups.group_id,groups.group_name,groups.unix_group_name ';
       $from = 'FROM '.$tracker.',groups ';
       $where = 'WHERE groups.group_id='.$tracker.'.group_id '.
-	'AND '.$tracker.'.status_id='.$status.' '.
+	'AND '.$tracker.'.status_id='.$openclosed.' '.
 	'AND ('.$tracker.'.priority >= '.$threshold.' OR  '.$tracker.'.date > '.$new_date_limit.') '.$showprivate;
 
       if ($role == "assignee")
-	{ $where .= 'AND '.$tracker.'.assigned_to='.$uid.' '; }
+	{
+	  $where .= 'AND ('.$tracker.'.assigned_to='.$uid.' '; 
+
+          # If the user is member of squads, add them now
+	  reset($usersquads);
+	  foreach ($usersquads as $squad_id) 
+	    { $where .= 'OR '.$tracker.'.assigned_to='.$squad_id.' '; }	    
+
+	  $where .= ' ) ';
+
+	}
       else
 	{
           # If the submitter is also the owner, we ll show it in
@@ -270,12 +278,13 @@ function my_item_list_buildsql ($tracker, $role="assignee", $threshold="5", $sta
 	    {
 	      # No restriction if we are not listing the items of the logged
 	      # in user: we are not in page where items can be hidden
-	      if ($uid)
+	      if ($uid != user_getid())
 		{ continue; }
 	      
 	      # This group is supposed to be hidden, just do a count; do it 
 	      # now.
 	      $rows = db_numrows(db_query('SELECT count('.$tracker.'.bug_id) as count '.$from.' '.$where.' AND '.$tracker.'.group_id="'.$current_group_id.'" GROUP BY bug_id LIMIT '.$sql_limit));
+
 	      # Feed the array so it nows exactly how many items we have
 	      # (array_fill exists only in PHP 4.2)
 	      for ($k=0; $k<$rows; $k++)
@@ -360,10 +369,17 @@ function my_item_list_buildsql ($tracker, $role="assignee", $threshold="5", $sta
 	  
 	  $select = 'SELECT '.$tracker.'.bug_id,'.$tracker.'.date,'.$tracker.'.priority,'.$tracker.'.resolution_id,'.$tracker.'.summary,groups.group_id,groups.group_name,groups.unix_group_name ';
 	  $from = ' FROM '.$tracker.',groups ';
-	  $where = ' WHERE groups.group_id='.$tracker.'.group_id AND '.$tracker.'.status_id='.$status.' AND '.$tracker.'.assigned_to='.$uid.' AND ('.$tracker.'.date > '.$new_date_limit.' AND '.$tracker.'.submitted_by<>'.$uid.') ';
+	  $where = ' WHERE groups.group_id='.$tracker.'.group_id AND '.$tracker.'.status_id='.$openclosed.' AND ('.$tracker.'.assigned_to='.$uid;
+
+          # If the user is member of squads, add them now
+	  reset($usersquads);
+	  foreach ($usersquads as $squad_id) 
+	    { $where .= ' OR '.$tracker.'.assigned_to='.$squad_id; }	  
+	  
+	  $where .= ') AND ('.$tracker.'.date > '.$new_date_limit.' AND '.$tracker.'.submitted_by<>'.$uid.') ';
 
 	      /*   } */
-	  
+
 	}
       
       # Go thru the list of groups the user belongs to
@@ -474,9 +490,12 @@ function my_item_list_extractdata ($sql, $tracker) {
 }
 
 # Print a list of data from what was in the hash
-function my_item_list_print ($role="assignee", $condensed=0) {
+function my_item_list_print ($role="assignee", $openclosed="open", $condensed=false) {
   global $item_data, $group_data, $items_per_groups, $maybe_missed_rows;
 
+  if ($openclosed == "closed") 
+    { $openclosed = 3; }
+
   # Break here if we have no results
   if (count($items_per_groups) < 1)
     {
@@ -488,7 +507,12 @@ function my_item_list_print ($role="assignee", $condensed=0) {
   # SQL limits, we may have missed others items because they are too many
   if ($maybe_missed_rows)
     { 
-      print '<span class="warn">'._("We found many items that match the current criteria. We had to set a limit at some point, some items that match the criteria may be missing for this list.").'</span><br />'; 
+      print '<div class="boxitem"><span class="xsmall"><span class="warn">'._("We found many items that match the current criteria. We had to set a limit at some point, some items that match the criteria may be missing for this list.").'</span></span></div>'; 
+      if (!$condensed)
+	{
+	  print '<br />';
+	}
+      
     }
   
 
@@ -549,7 +573,7 @@ function my_item_list_print ($role="assignee", $condensed=0) {
 	      $status = $group_data[$current_group_id.$tracker.$item_data['status'][$thisitem]];
 	      
               # Print directly, to avoid putting too much things in memory
-	      print '<div class="'.utils_get_priority_color($item_data['priority'][$thisitem], $status).'">'.
+	      print '<div class="'.utils_get_priority_color($item_data['priority'][$thisitem], $openclosed).'">'.
 		'<a href="'.$GLOBALS['sys_home'].$tracker.'/?'.$current_item_id.'" class="block">'.
 		'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" class="icon" alt="'.$tracker.'" /> '.
 		stripslashes($item_data['summary'][$thisitem]).
