@@ -5,7 +5,6 @@
 # $Id: menu.php 5379 2006-02-15 14:11:03Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew (was in Layout.class)
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
@@ -50,7 +49,8 @@ function pagemenu ($params)
 
   # Print topmenu title 
   # We use javascript for browsers that does not support CSS correctly
-  if (strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") && !$_GET["printer"] &&
+  if (is_broken_msie() && 
+      !$_GET["printer"] &&
       !$GLOBALS['stone_age_menu'])
     {
 
@@ -170,7 +170,7 @@ function pagemenu_submenu_title ($title, $url, $selected=0, $available=1, $help=
 # talking about it on savane-dev.
 # DONT CHANGE width, margin and padding size, or you ll be very sorry
 # for MSIE users
-  if (strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") && !$_GET["printer"])
+  if (is_broken_msie() && !$_GET["printer"])
     {
       # normally we should have white-space: nowrap; but then MSIE make 
       # the text disappear on mouse out.
@@ -311,7 +311,7 @@ function pagemenu_group ()
   if (member_check(0, $group_id, 'A'))
     { $is_admin = 1; }
 
-  $project=project_get_object($group_id);
+  $project = project_get_object($group_id);
   if ($project->isError())
     { return; }
 
@@ -338,6 +338,7 @@ function pagemenu_group ()
 	pagemenu_submenu_entry(_("Edit Public Info"),$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$project->getUnixName()).
 	pagemenu_submenu_entry(_("Select Features"),$GLOBALS['sys_home'].'project/admin/editgroupfeatures.php?group='.$project->getUnixName()).
 	pagemenu_submenu_entry(_("Manage Members"),$GLOBALS['sys_home'].'project/admin/useradmin.php?group='.$project->getUnixName()).
+	pagemenu_submenu_entry(_("Manage Squads"),$GLOBALS['sys_home'].'project/admin/squadadmin.php?group='.$project->getUnixName()).
 	pagemenu_submenu_entry(_("Set Permissions"),$GLOBALS['sys_home'].'project/admin/userperms.php?group='.$project->getUnixName()).
 	pagemenu_submenu_entry(_("Set Notifications"),$GLOBALS['sys_home'].'project/admin/editgroupnotifications.php?group='.$project->getUnixName()).
 	pagemenu_submenu_entry(_("Show History"),$GLOBALS['sys_home'].'project/admin/history.php?group='.$project->getUnixName()).
@@ -800,48 +801,70 @@ function pagemenu_group_trackers ($tracker)
 # Menu specific to the site admin pages
 function pagemenu_siteadmin ()
 {
-  pagemenu_submenu_title(_("Main"), 
-			 $GLOBALS['sys_home'].'siteadmin/', 
-			 SUBCONTEXT == 'browse');
-  pagemenu_submenu_content(pagemenu_submenu_entry(_("Pending Project Registrations"),
+  pagemenu_submenu_title(_("Configuration"), 
+			 $GLOBALS['sys_home'].'siteadmin/?func=configure', 
+			 SUBCONTEXT == 'configure');
+  pagemenu_submenu_content(pagemenu_submenu_entry(_("Test System Configuration"),
+						  $GLOBALS['sys_home'].'siteadmin/retestconfig.php').
+
+
+			   pagemenu_submenu_entry(_("Configure Group Types"),
+						  $GLOBALS['sys_home'].'siteadmin/group_type.php').
+			   pagemenu_submenu_entry(_("Configure People Area"),
+						  $GLOBALS['sys_home'].'people/admin/'));
+  pagemenu_submenu_end();
+
+  pagemenu_submenu_title(_("Management"), 
+			 $GLOBALS['sys_home'].'siteadmin/?func=manage',
+			 SUBCONTEXT == 'manage');
+
+  # If the current page shows a group edition page, add extra links
+  unset($extralinks);
+  if (SUBCONTEXT == 'manage' && $GLOBALS['group_name'])
+    {
+      
+      $extralinks = pagemenu_submenu_entry_separator().
+	pagemenu_submenu_entry('<strong>'._("Currently Shown Project:").'</strong>',
+			       '#').
+	pagemenu_submenu_entry(_("Administer"),
+			       $GLOBALS['sys_home'].'project/admin/?group='.$GLOBALS['group_name']).
+	pagemenu_submenu_entry(_("Edit Public Info"),$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$GLOBALS['group_name']).
+
+	pagemenu_submenu_entry(_("Select Features"),
+			       $GLOBALS['sys_home'].'project/admin/editgroupfeatures.php?group='.$GLOBALS['group_name']).
+	pagemenu_submenu_entry(_("Manage Members"),
+			       $GLOBALS['sys_home'].'project/admin/useradmin.php?group='.$GLOBALS['group_name']).
+	pagemenu_submenu_entry(_("Show History"),
+			       $GLOBALS['sys_home'].'project/admin/history.php?group='.$GLOBALS['group_name']);	
+    }
+  
+  pagemenu_submenu_content(pagemenu_submenu_entry(_("Browse Pending Project Registrations"),
 						  $GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;go_report=Apply').
-			   pagemenu_submenu_entry(_("Site news approval"),
+			   pagemenu_submenu_entry(_("Approve News"),
 						  $GLOBALS['sys_home'].'news/approve.php?group='.$GLOBALS['sys_unix_group_name']).
-			   pagemenu_submenu_entry(_("Most Recent Logins"),
+			   pagemenu_submenu_entry_separator().
+			   pagemenu_submenu_entry(_("Browse Groups List"), 
+						  $GLOBALS['sys_home'].'siteadmin/grouplist.php').
+			   pagemenu_submenu_entry(_("Browse Users List"), 
+						  $GLOBALS['sys_home'].'siteadmin/userlist.php').
+			   $extralinks);
+			   
+
+  pagemenu_submenu_end();
+  
+
+  pagemenu_submenu_title(_("Monitoring"), 
+			 $GLOBALS['sys_home'].'siteadmin/?func=monitor', 
+			 SUBCONTEXT == 'monitor');
+  
+  pagemenu_submenu_content(pagemenu_submenu_entry(_("Monitor Spams"),
+						  $GLOBALS['sys_home'].'siteadmin/spamlist.php').
+
+
+			   pagemenu_submenu_entry(_("Check Last Logins"), 
 						  $GLOBALS['sys_home'].'siteadmin/lastlogins.php'));
   pagemenu_submenu_end();
 
-  pagemenu_submenu_title(_("Group Types"), 
-			 $GLOBALS['sys_home'].'siteadmin/group_type.php', 
-			 SUBCONTEXT == 'grouptype');
-  pagemenu_submenu_end();
-
-  pagemenu_submenu_title(_("Groups"), 
-			 $GLOBALS['sys_home'].'siteadmin/grouplist.php', 
-			 SUBCONTEXT == 'groupedit'); 
-  if (SUBCONTEXT == 'groupedit' && $GLOBALS['group_name'])
-    {
-      pagemenu_submenu_content(pagemenu_submenu_entry(_("This Project Admin"),
-						      $GLOBALS['sys_home'].'project/admin/?group='.$GLOBALS['group_name']).
-			       pagemenu_submenu_entry(_("This Project Active Features"),
-						      $GLOBALS['sys_home'].'project/admin/editgroupfeatures.php?group='.$GLOBALS['group_name']).
-			       pagemenu_submenu_entry(_("Manage This Project Members"),
-						      $GLOBALS['sys_home'].'project/admin/useradmin.php?group='.$GLOBALS['group_name']).
-			       pagemenu_submenu_entry(_("Show This Project History"),
-						      $GLOBALS['sys_home'].'project/admin/history.php?group='.$GLOBALS['group_name']));
-    }
-  pagemenu_submenu_end();
-
-  pagemenu_submenu_title(_("Users"), 
-			 $GLOBALS['sys_home'].'siteadmin/userlist.php', 
-			 SUBCONTEXT == 'useredit');
-  pagemenu_submenu_end();
-
-  pagemenu_submenu_title(_("Contributor Wanted"), 
-			 $GLOBALS['sys_home'].'people/admin/');
-  pagemenu_submenu_end();
-
-
 }
 
 ?>
