@@ -2,12 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 5561 2006-08-14 08:41:55Z toddy $
+# $Id: general.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -76,6 +75,33 @@ function people_show_category_table()
   return $return;
 }
 
+# Show the project types, and a form to show only the related job
+function people_show_grouptype_table()
+{
+  $title_arr=array();
+  $title_arr[]=_("Project type");
+
+  $return .= html_build_list_table_top ($title_arr);
+  $sql="SELECT group_type.type_id, group_type.name, COUNT(people_job.job_id) AS count FROM group_type JOIN (groups JOIN people_job ON groups.group_id = people_job.group_id) ON group_type.type_id = groups.type GROUP BY type_id ORDER BY type_id";
+  $result=db_query($sql);
+  $rows=db_numrows($result);
+  if (!$result || $rows < 1)
+    {
+      $return .= '<tr><td><h2>'._("No Categories Found").'</h2></td></tr>';
+    }
+  else
+    {
+      for ($i=0; $i<$rows; $i++)
+	{
+	  $return .= '<tr class="'. utils_get_alt_row_color($i) .'"><td><a href="'.$GLOBALS['sys_home'].'people/?type_id='.
+	     db_result($result,$i,'type_id') .'">'.
+	     db_result($result,$i,'name') .'</a> ('. db_result($result,$i,'count') .')</td></tr>';
+	}
+    }
+  $return .= '</table>';
+  return $return;
+}
+
 function people_show_category_list()
 {
 
@@ -383,6 +409,24 @@ function people_project_jobs_rows($group_id)
   return $rows;
 }
 
+# Show open jobs for the given group type
+function people_show_grouptype_jobs($type_id, $edit=0)
+{
+  $sql="SELECT people_job.group_id, people_job.job_id, groups.group_name,
+               groups.unix_group_name, groups.type, people_job.title,
+               people_job.date, people_job_category.name AS category_name
+    FROM people_job, people_job_category, groups,group_type
+    WHERE people_job.category_id = people_job_category.category_id
+          AND people_job.group_id = groups.group_id
+          AND groups.type = group_type.type_id
+          AND people_job.status_id = 1
+          AND type_id = '$type_id'
+    ORDER BY people_job.category_id, groups.group_name";
+  $result=db_query($sql);
+
+  return people_show_job_list($result, $edit);
+}
+
 # skill.php
 
 function people_skill_box($name='skill_id',$checked='xyxy')
