@@ -2,10 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php 5970 2006-09-26 08:34:01Z yeupou $
+# $Id: project_home.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
-# Copyright 2000-2003 (c) Free Software Foundation
 #
 # Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                         Yves Perrin <yves.perrin--cern.ch>
@@ -69,7 +68,7 @@ if ($adminsnum > 0)
   }
 
 #count of developers on this project
-$membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P'"));
+$membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P' AND admin_flags<>'SQD'"));
 print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
 printf(ngettext("%s member", "%s members", $membersnum[count]),'<strong>'.$membersnum[count].'</strong>');
 
@@ -119,13 +118,13 @@ if ($project->getTypeDescription())
 
 if ($project->getLongDescription())
   {
-    print "<p>" . utils_make_links(nl2br($project->getLongDescription()), $group_id)."</p>\n";
+    print "<p>".markup_full(htmlspecialchars($project->getLongDescription()))."</p>\n";
   }
 else
   {
     if ($project->getDescription())
       {
-        print "<p>" . $project->getDescription()."</p>\n";
+        print "<p>" .$project->getDescription()."</p>\n";
       }
     else
       {
