@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php 5834 2006-09-18 14:55:56Z yeupou $
+# $Id: sendmail.php 6475 2006-11-28 15:17:12Z yeupou $
 #
 #  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
@@ -31,14 +31,19 @@ function sendmail_mail ($from,
 			$to, 
 			$subject, 
 			$message,  #4
-			$savannah_project=0, 
-			$savannah_artifact=0, 
-			$savannah_artifact_id=0, 
+			$savane_project=0, 
+			$savane_tracker=0, 
+			$savane_item_id=0, 
 			$reply_to=0, # 8
 			$additional_headers=0,
 			$exclude_list=0) 
 {
 
+  global $int_delayspamcheck;
+
+  # Check if $delayspamcheck makes sense
+  if (!$savane_project || !$savane_tracker || !$savane_item_id)
+    { unset($int_delayspamcheck); }
 
   # Make sure that users cannot insert malicious content
   # (apart in message, which is not part of the headers)
@@ -46,18 +51,27 @@ function sendmail_mail ($from,
   $from = stripslashes($from);
   $subject = stripslashes($subject);
 
+  # Clean the markup
+  $message = markup_textoutput($message);
+
   # Make sure the message respect the 78chars max width
   # Make also sure we havent got excessive slashes escaping
   $message = wordwrap($message, 78);
 
   # Convert ; into
   $to = ereg_replace(";", ",", $to);
+
   # Transform $to in an ordered list, without duplicates
   # (remove blankspaces)
   # FIXME: this is questionable, as it disallow stuff like 
   #    "Dupont Lajoie" <dupont@devnull.net>
   # and we should allow that.
-  $to = array_unique(explode(",", ereg_replace(" ", "", $to)));
+  # (check on $to necessary because explode returns a one element array in case
+  # iet has to explode an empty string and this screws the code later on)
+  if ($to != "") 
+    { $to = array_unique(explode(",", ereg_replace(" ", "", $to))); } 
+  else 
+    { $to = array(); }
 
   # If $from is a login name, write nice From: field
   $fromuid = user_getid($from);
@@ -72,26 +86,44 @@ function sendmail_mail ($from,
   $more_headers = "From: ".sendmail_encode_header_content($from)."\n";
   if ($reply_to)
     { $more_headers .= "Reply-To: ".$reply_to."\n"; }
-  $more_headers .= "X-Savane-Server: ".$_SERVER['SERVER_NAME'].":".$_SERVER['SERVER_PORT']." [".$_SERVER['SERVER_ADDR']."]\n";
+
+  # Add a signature for the server (not if delayed, because it will be added
+  # we the mail will be actually sent)
+  if (!$int_delayspamcheck)
+    {  
+      $more_headers .= "X-Savane-Server: ".$_SERVER['SERVER_NAME'].":".$_SERVER['SERVER_PORT']." [".$_SERVER['SERVER_ADDR']."]\n";
+    }
 
   # Necessary for proper utf-8 support
   $more_headers .= "MIME-Version: 1.0\n";
   $more_headers .= "Content-Type: text/plain;charset=UTF-8\n";
 
   # Savane details
-  if ($savannah_project) 
-    { $more_headers .= "X-Savane-Project: ".$savannah_project."\n"; }
-  if ($savannah_artifact) 
-    { $more_headers .= "X-Savane-Tracker: ".$savannah_artifact."\n"; }  
-  if ($savannah_artifact_id) 
-    { $more_headers .= "X-Savane-Item-ID: ".$savannah_artifact_id."\n"; }
+  if ($savane_project) 
+    { $more_headers .= "X-Savane-Project: ".$savane_project."\n"; }
+  if ($savane_tracker) 
+    { $more_headers .= "X-Savane-Tracker: ".$savane_tracker."\n"; }
+  $savane_comment_id = 0;
+  if ($savane_item_id) 
+    {
+      # Look if there is a (internal) comment id set 
+      if (strpos($savane_item_id, ":"))
+	{
+	  list($savane_item_id, $savane_comment_id) = split(":", $savane_item_id);
+	}
+      $more_headers .= "X-Savane-Item-ID: ".$savane_item_id."\n"; 
+    }
   if ($additional_headers) 
     { $more_headers .= $additional_headers."\n";  }
 
   # User details.
   # Tell what is the user agent, tell which authenticated user made
   # the mail to be sent
-  $more_headers .= "User-Agent: ".$_SERVER['HTTP_USER_AGENT']."\n";
+  if (!$int_delayspamcheck)
+    {  
+      $more_headers .= "User-Agent: ".$_SERVER['HTTP_USER_AGENT']."\n";
+    }
+
   if (user_isloggedin())
     {
       $more_headers .= "X-Apparently-From: ".$_SERVER['REMOTE_ADDR']." (Savane authenticated user ".user_getname(user_getid()).")\n";
@@ -105,21 +137,25 @@ function sendmail_mail ($from,
   $msg_id = sendmail_create_msgid();
   $more_headers .= "Message-Id: <".$msg_id.">\n";
   # Add refs
-  if ($savannah_artifact && $savannah_artifact_id)
+  if ($savane_tracker && $savane_item_id)
     {      
-      $more_headers .= "References: ".trackers_get_msgid($savannah_artifact, $savannah_artifact_id)."\n";
-      $more_headers .= "In-Reply-To: ".trackers_get_msgid($savannah_artifact, $savannah_artifact_id, true)."\n";
+      $more_headers .= "References: ".trackers_get_msgid($savane_tracker, $savane_item_id)."\n";
+      $more_headers .= "In-Reply-To: ".trackers_get_msgid($savane_tracker, $savane_item_id, true)."\n";
     }
 
-  # Add a signature for the server
-  $message .= "\n\n_______________________________________________
+  # Add a signature for the server (not if delayed, because it will be added
+  # we the mail will be actually sent)
+  if (!$int_delayspamcheck)
+   {
+     $message .= "\n\n_______________________________________________
   ".sprintf(_("Message sent via/by %s"), $GLOBALS['sys_name'])."
   http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."\n";
+   }
 
   # Register the message id for future references
-  if ($savannah_artifact && $savannah_artifact_id)
+  if ($savane_tracker && $savane_item_id)
     {
-      trackers_register_msgid($msg_id, $savannah_artifact, $savannah_artifact_id);
+      trackers_register_msgid($msg_id, $savane_tracker, $savane_item_id);
     }
 
   # If there is an exclude list, create an array 
@@ -128,7 +164,7 @@ function sendmail_mail ($from,
   if ($exclude_list)
     {
       $exclude_list = ereg_replace(";", ",", $exclude_list);
-       $exclude = array_unique(explode(",", ereg_replace(" ", "", $exclude_list)));
+      $exclude = array_unique(explode(",", ereg_replace(" ", "", $exclude_list)));
     }
 
   while (list(,$v) = each($exclude)) 
@@ -140,21 +176,74 @@ function sendmail_mail ($from,
 
   # Forge the real to list, by parsing every item of the $to list
   unset($real_to);
+
+  # Do a first run to convert squads by users 
+  $to2 = array();
+  $squad_seen_before = array();
+  while (list(,$v) = each($to)) 
+    {     
+      if (ctype_digit($v)) 
+	{ $touid = $v; } 
+      else 
+	{ $touid = user_getid($v); }
+
+      # Squad exists in the exclude array? Skip it
+      if ($exclude[$v])
+        { continue; }
+
+      # Already handled?
+      if ($squad_seen_before[$v])
+	{ continue; }
+
+      # Record that we handled this already
+      $squad_seen_before[$v] = true;
+
+      # If an address is a squad username, push in all the relevant users 
+      # uid
+      if (!strpos($v, "@")) 
+	{
+	  if (user_exists($touid, true)) 
+            { 
+              # Exists in the exclude array? Skip it
+	      if (is_array($exclude) && array_key_exists(user_getname($touid), $exclude))
+		{ continue; }
+	      
+              # If we get here, we have a squad and we will store all the
+              # squad members uid
+	      $sql_squad = "SELECT user_id FROM user_squad WHERE squad_id='$touid'";
+	      $result_squad = db_query($sql_squad);
+	      if ($result_squad && db_numrows($result_squad) > 0) 
+		{
+		  while ($thisuser = db_fetch_array($result_squad))
+		    {
+		      $to2[] = $thisuser['user_id'];
+		    }
+		}
+	      
+	      # No need to go further, this squad was handled
+	      continue;
+	    }
+	}
+
+      # If we get here, it means that we have an address that is not squad
+      # related have we keep it for the next run
+      $to2[] = $v;      
+    }
+
+
+  # Second run, we should have only real users here, no squads
   $list = array();
   $user_subject = array();
   $user_name  = array();
   $seen_before = array();
-
-  while (list($k,$v) = each($to)) 
-
+  while (list(,$v) = each($to2)) 
     {
-      if (is_numeric($v)) {
-        $touid = $v;
-      } else {
-        $touid = user_getid($v);
-      }
+      if (is_numeric($v)) 
+	{ $touid = $v; } 
+      else 
+	{ $touid = user_getid($v); }
 
-      # Exists in the exclude array? Skip it
+      # User exists in the exclude array? Skip it
       if ($exclude[$v])
         { continue; }
 
@@ -163,9 +252,8 @@ function sendmail_mail ($from,
 	{ continue; }
       
       # Record that we handled this already
-      $seen_before[$b] = true;
+      $seen_before[$v] = true;
    
-
       $i++;
       # If an address is a username, get the email address from
       # the database.
@@ -197,7 +285,7 @@ function sendmail_mail ($from,
 	      if (user_get_preference("subject_line", $touid) != "")
 		{
 		  $list[$i] = $v;
-		  $user_subject[$v] = sendmail_format_subject_line(user_get_preference("subject_line", $touid), $savannah_project, $savannah_artifact, $savannah_artifact_id)." ".$subject;
+		  $user_subject[$v] = sendmail_format_subject_line(user_get_preference("subject_line", $touid), $savane_project, $savane_tracker, $savane_item_id)." ".$subject;
 		  $user_name[$v] = user_getrealname($touid, 1)." <".$thisuser_email.">";
 		  
 		  $seen_before[$thisuser_email] = true;
@@ -252,9 +340,9 @@ function sendmail_mail ($from,
     } 
 
   # Add eventually info on the subject
-  if ($savannah_artifact && $savannah_artifact_id) 
+  if ($savane_tracker && $savane_item_id) 
     { 
-      $subject = "[".utils_get_tracker_prefix($savannah_artifact)." #".$savannah_artifact_id."] ".$subject; 
+      $subject = "[".utils_get_tracker_prefix($savane_tracker)." #".$savane_item_id."] ".$subject; 
     }
 
    # Remove the extra ", " at the end of the list
@@ -279,18 +367,33 @@ function sendmail_mail ($from,
    if ($real_to) 
         {
 	  # Normally, $real_to should not contain duplicates
-	  $ret .= mail(sendmail_encode_header_content($real_to), sendmail_encode_header_content($subject), $message, $more_headers);
-	  fb(sprintf(_("Mail sent to %s"), utils_email($real_to, 1)));
+	  if (!$int_delayspamcheck)
+	    {
+	      $ret .= mail(sendmail_encode_header_content($real_to), sendmail_encode_header_content($subject), $message, $more_headers);
+	      fb(sprintf(_("Mail sent to %s"), utils_email($real_to, 1)));
+	    }
+	  else
+	    {
+	      # Wait to be checked for spams
+	      db_query("INSERT INTO trackers_spamcheck_queue_notification (artifact, item_id, comment_id, to_header, other_headers, subject_header, message) VALUES ('$savane_tracker', '$savane_item_id', '$savane_comment_id','".addslashes(sendmail_encode_header_content($real_to))."','".addslashes($more_headers)."','".addslashes(sendmail_encode_header_content($subject))."','".addslashes($message)."')");
+	      
+	    }
 	} 
 
    # Send mails with specific subject line
    while (list(,$v) = each($list)) 
      {
-        $ret .= mail(sendmail_encode_header_content($user_name[$v]), sendmail_encode_header_content($user_subject[$v]), $message, $more_headers);
-	fb(sprintf(_("Mail sent to %s"), utils_email($user_name[$v], 1)));
-     }  
-
-   
+       if (!$int_delayspamcheck)
+	 {
+	   $ret .= mail(sendmail_encode_header_content($user_name[$v]), sendmail_encode_header_content($user_subject[$v]), $message, $more_headers);
+	   fb(sprintf(_("Mail sent to %s"), utils_email($user_name[$v], 1)));
+	 }
+       else
+	 {
+           # Wait to be checked for spams
+	   db_query("INSERT INTO trackers_spamcheck_queue_notification (artifact, item_id, comment_id, to_header, other_headers, subject_header, message) VALUES ('$savane_tracker', '$savane_item_id', '$savane_comment_id','".addslashes(sendmail_encode_header_content($user_name[$v]))."','".addslashes($more_headers)."','".addslashes(sendmail_encode_header_content($user_subject[$v]))."','".addslashes($message)."')");
+	 }
+     }     
       
   return $ret; 
 }
@@ -366,13 +469,13 @@ documentation first? Try to provide any potentially useful information you can t
   print $HTML->box_bottom();
 }
 
-function sendmail_format_subject_line ($subject_line, $savannah_project="", $savannah_artifact="", $savannah_artifact_id="") 
+function sendmail_format_subject_line ($subject_line, $savane_project="", $savane_tracker="", $savane_item_id="") 
 {
 
   $subject_line = ereg_replace("%SERVER", $GLOBALS['sys_default_domain'], $subject_line);
-  $subject_line = ereg_replace("%PROJECT", $savannah_project, $subject_line);
-  $subject_line = ereg_replace("%TRACKER", $savannah_artifact, $subject_line);
-  return ereg_replace("%ITEM", "#".$savannah_artifact_id, $subject_line);
+  $subject_line = ereg_replace("%PROJECT", $savane_project, $subject_line);
+  $subject_line = ereg_replace("%TRACKER", $savane_tracker, $subject_line);
+  return ereg_replace("%ITEM", "#".$savane_item_id, $subject_line);
 }
 
 function sendmail_create_msgid ()
