@@ -2,12 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: session.php 5697 2006-09-08 15:48:06Z yeupou $
+# $Id: session.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Derek Feichtinger <derek.feichtinger--cern.ch>
 # 
 # The Savane project is free software; you can redistribute it and/or
@@ -66,6 +65,11 @@ function session_login_valid($form_loginname,
     } 
   else 
     {
+      if ($usr['status'] == 'SQD') 
+	{ 
+	  # squad account, silently exit
+	  return false;
+	} 
       if ($usr['status'] == 'P') 
 	{ 
 	  #account pending
@@ -296,50 +300,44 @@ function session_require_test($req)
 
 function session_require($req) 
 {
-  /*
-		SV admins always return true
-  */
   if (user_is_super_user()) 
-    {
-      return true;
-    }
+    { return true; }
   
   if ($req['group']) 
     {
-      $query = "SELECT user_id FROM user_group WHERE user_id=" . user_getid()
-	 . " AND group_id=$req[group]";
+      $query = "SELECT user_id FROM user_group WHERE user_id=".user_getid()." AND group_id='$req[group]'";
       if ($req['admin_flags']) 
 	{
-	  $query .= " AND admin_flags = '$req[admin_flags]'";	
+	  $query .= " AND admin_flags='$req[admin_flags]'";	
 	}
-    
-      if ((db_numrows(db_query($query)) < 1) || !$req['group']) 
+      
+      if (!db_numrows(db_query($query))) 
 	{
-	  exit_error("Insufficient Group Access","You do not have permission to "
-		     . "view this page.");
+	  exit_permission_denied();
 	}
+      
+      return true;
     }
   elseif ($req['user']) 
     {
       if (user_getid() != $req['user']) 
-	{	
-	  exit_error("Insufficient User Access","You do not have permission to "
-		     . "view this page.");
+	{		  
+	  exit_permission_denied();
 	}
+
+      return true;
     }
   elseif ($req['isloggedin']) 
     {
       if (!user_isloggedin()) 
 	{
-	  exit_error("Required Login","In order to view this page, you must "
-		     . "be logged in.");
+	  exit_not_logged_in();
 	}
+      return true;
     } 
   else 
     {
-      exit_error("Insufficient Access","Probably by mangling a URL, you have attempted "
-		 . "to reach a part of the site for which you do not have access. This can "
-		 . "probably be fixed by properly navigating through the site.");
+      exit_missing_param();
     }
 }
 
