@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 5736 2006-09-11 08:55:38Z yeupou $
+# $Id: general.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 2004-2004 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
@@ -86,7 +86,7 @@ function stats_getitems($tracker, $only_open="",$period="")
     { $period = " AND $period"; }
   
  
-  return stats_get_generic("SELECT count(*) AS count FROM $tracker WHERE group_id<>'100' $only_open $period");
+  return stats_get_generic("SELECT count(*) AS count FROM $tracker WHERE group_id<>'100' AND spamscore < 5 $only_open $period");
 }
 
 function stats_getthemeusers($theme="") 
