@@ -2,9 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php 5894 2006-09-21 07:44:53Z yeupou $
+# $Id: data.php 6495 2007-04-09 18:07:41Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
+#
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
@@ -1274,17 +1275,18 @@ function trackers_data_get_valid_bugs ($group_id=false,$item_id='')
   return db_query($sql);
 }
 
-function trackers_data_get_followups ($item_id=false, $rorder=true)
+
+function trackers_data_get_followups ($item_id=false, $rorder=false)
 {
-  if ($rorder == "true")
+  if ($rorder == true)
     { $rorder = "DESC"; }
   else
     { $rorder = "ASC"; }
 
-  $sql="SELECT DISTINCT ".ARTIFACT."_history.bug_history_id,".ARTIFACT."_history.field_name,".ARTIFACT."_history.old_value,".ARTIFACT."_history.date,user.user_name,user.realname,".ARTIFACT."_field_value.value AS comment_type ".
+  $sql="SELECT DISTINCT ".ARTIFACT."_history.bug_history_id,".ARTIFACT."_history.field_name,".ARTIFACT."_history.old_value,".ARTIFACT."_history.spamscore,".ARTIFACT."_history.new_value,".ARTIFACT."_history.date,user.user_name,user.realname,user.user_id,".ARTIFACT."_field_value.value AS comment_type ".
      "FROM ".ARTIFACT."_history,".ARTIFACT."_field_value,".ARTIFACT."_field,".ARTIFACT.",user ".
      "WHERE ".ARTIFACT."_history.bug_id='$item_id' ".
-     "AND ".ARTIFACT."_history.field_name = 'details' ".
+     "AND (".ARTIFACT."_history.field_name = 'details' OR ".ARTIFACT."_history.field_name = 'svncommit') ".
      "AND ".ARTIFACT."_history.mod_by=user.user_id ".
      "AND ".ARTIFACT."_history.bug_id=".ARTIFACT.".bug_id ".
      "AND ".ARTIFACT."_history.type = ".ARTIFACT."_field_value.value_id ".
@@ -1310,6 +1312,7 @@ function trackers_data_get_history ($item_id=false)
      "FROM ".ARTIFACT."_history,user ".
      "WHERE ".ARTIFACT."_history.mod_by=user.user_id ".
      "AND ".ARTIFACT."_history.field_name <> 'details' ".
+     "AND ".ARTIFACT."_history.field_name <> 'svncommit' ".
      "AND bug_id='$item_id' ORDER BY ".ARTIFACT."_history.date DESC";
   return db_query($sql);
 }
@@ -1342,7 +1345,6 @@ function trackers_data_add_history ($field_name,
 				    $force=0)
 
 {
-
   # If no artifact is defined, get the default one
   if (!$artifact)
     {
@@ -1362,6 +1364,14 @@ function trackers_data_add_history ($field_name,
       $user=user_getid();
     }
 
+  # If spamscore is relevant (if it is a comment), set it, otherwise go with
+  # 0
+  $spamscore = 0;
+  if ($field_name == 'details')
+    {
+      $spamscore = spam_get_user_score($user);
+    }
+
   # If type has a value add it into the sql statement (this is only for
   # the follow up comments (details field))
   if ($type)
@@ -1379,9 +1389,25 @@ function trackers_data_add_history ($field_name,
     }
 
 
-  $sql="INSERT INTO ".$artifact."_history (bug_id,field_name,old_value,new_value,mod_by,date $fld_type) ".
-     "VALUES ('$item_id','$field_name','$old_value','$new_value','$user','".time()."' $val_type)";
-  return db_query($sql);
+  $sql="INSERT INTO ".$artifact."_history (bug_id,field_name,old_value,new_value,mod_by,date,spamscore,ip $fld_type) ".
+     "VALUES ('$item_id','$field_name','$old_value','$new_value','$user','".time()."','$spamscore','".$_SERVER['REMOTE_ADDR']."' $val_type)";
+  $result = db_query($sql);
+  
+  spam_set_item_default_score($item_id, 
+			      db_insertid($result),
+			      $artifact,
+			      $spamscore, 
+			      $user);
+
+  # Add to spamcheck queue if necessary (will temporary set the spamscore to
+  # 5, if necessary)
+  # Useless if already considered to be spam.
+  if ($spamscore < 5)
+    {  
+      spam_add_to_spamcheck_queue($item_id, db_insertid($result), $artifact, $group_id, $spamscore); 
+    }
+
+  return $result;
 }
 
 
@@ -1446,7 +1472,7 @@ function trackers_data_handle_update ($group_id,
   # See which fields changed during the modification
   # and if we must keep history then do it. Also add them to the update
   # statement
-  $changes = array();
+  # ($changes was initialized in index, as it is used by other functions)
   reset($vfl);
   while (list($field,$value) = each($vfl))
     {
@@ -1566,6 +1592,11 @@ function trackers_data_handle_update ($group_id,
 	    trackers_field_display($field,$group_id,$old_value,false,false,true,true);
 	  $changes[$field]['add']=
 	     trackers_field_display($field,$group_id,$value,false,false,true,true);
+	  
+	  # Keep track of the change real numeric values
+	  $changes[$field]['del-val']= $old_value;
+	  $changes[$field]['add-val']= $value;
+
 
           # Register transition id, if not empty
           if ($field_transition_id != '')
@@ -1628,6 +1659,7 @@ function trackers_data_handle_update ($group_id,
   if ($details != '')
     {
       $change_exists = 1;
+      fb(_("Comment added"), 0);
       trackers_data_add_history('details',
 				htmlspecialchars($details),
 				'',
@@ -1636,12 +1668,27 @@ function trackers_data_handle_update ($group_id,
       $changes['details']['add'] = stripslashes($details);
       $changes['details']['type'] =
 	trackers_data_get_value('comment_type_id',$group_id, $vfl['comment_type_id']);
+      
+      # Add poster in CC
+      if (!user_get_preference("skipcc_postcomment"))
+	{
+	  trackers_add_cc($item_id,
+			  $group_id,
+			  user_getid(),
+			  "-COM-",
+			  $changes); 
+                               # use a flag as comment, because if we 
+		               # translate the string now, people will get
+ 		               # the translation of the submitter when they
+                               # read the item, not necessarily the one they
+		               # want
+	}
     }
 
   # If we are on the cookbook, the original submission have been details
   if (ARTIFACT == 'cookbook')
     {
-      $details = $vfl['details'];
+      $details = htmlspecialchars($vfl['details']);
       $previous_details = db_result($result,0,'details');
 
       if ($details != $previous_details)
@@ -1703,7 +1750,8 @@ function trackers_data_handle_update ($group_id,
               $changes['Depends on']['add'] = $art." #".$dep;
               $change_exists = 1;
 
-	      # Check if we're supposed to send all modifications to an address
+	      # Check if we are
+	      # supposed to send all modifications to an address
 	      list($address, $sendall) = trackers_data_get_item_notification_info($dep, $art, 1);
 	      if (($sendall == 1) && (trim($address) != ""))
                 {
@@ -1734,6 +1782,23 @@ function trackers_data_handle_update ($group_id,
 	 " WHERE bug_id='$item_id' AND group_id='$group_id'";
 
       $result=db_affected_rows(db_query($sql));
+
+      # Add CC (CC in case of comment would have been already entered,
+      # if there is only a comment, we should not end up here)
+      if (!user_get_preference("skipcc_updateitem"))
+	{
+	  trackers_add_cc($item_id,
+			  $group_id,
+			  user_getid(),
+			  "-UPD-",
+			  $changes); 
+                               # use a flag as comment, because if we 
+		               # translate the string now, people will get
+ 		               # the translation of the submitter when they
+                               # read the item, not necessarily the one they
+		               # want
+	}
+
     }
   else
     {
@@ -1786,8 +1851,8 @@ function trackers_data_reassign_item ($item_id,
 
       if ($new_group_id == $group_id && ARTIFACT == $reassign_change_artifact)
 	{
-	  fb(_("No reassignation required or possible."));
-	  break;
+	  fb(_("No reassignation required or possible."), 1);
+	  return false;
 	}
 
       $now=time();
@@ -1809,10 +1874,10 @@ function trackers_data_reassign_item ($item_id,
       if (!$reassign_change_artifact)
 	{
 	  fb(_("Unable to find out to which artifact the item is to be reassigned, exiting."), 1);
-	  return 0;
+	  return false;
 	}
 
-		# move item
+      # move item
       $result = db_query("INSERT INTO ".$reassign_change_artifact.
 			 " (group_id,status_id,date,severity,submitted_by,summary,details,priority,planned_starting_date,planned_close_date,percent_complete,originator_email)".
 			 " VALUES ".
@@ -1832,7 +1897,7 @@ function trackers_data_reassign_item ($item_id,
       if (!$result)
 	{
 	  fb(_("Unable to create a new item."), 1);
-	  return 0;
+	  return false;
 	}
       else
 	{
@@ -1845,7 +1910,7 @@ function trackers_data_reassign_item ($item_id,
       if (!$new_item_id)
 	{
 	  fb(_("Unable to find the ID of the new item."), 1);
-	  return 0;
+	  return false;
 	}
 
       # Update items history
@@ -1916,9 +1981,8 @@ function trackers_data_reassign_item ($item_id,
 	    }
 	}
 
-      # Make sure there's no \' remaining
+      # Make sure there is no \' remaining
       $comment = ereg_replace("'", " ", $comment);
-
       $sql = "INSERT INTO ".$reassign_change_artifact."_history ".
 	 "(bug_id,field_name,old_value,mod_by,date,type)".
 	 " VALUES ".
@@ -1997,8 +2061,20 @@ function trackers_data_reassign_item ($item_id,
 	 "'100')";
       db_query($sql);
 
+      # Now send the notification (this must be done here, because we got
+      # here the proper new id, etc)
+      list($additional_address, $sendall) = trackers_data_get_item_notification_info($new_item_id, $reassign_change_artifact, 1);
+      if (($sendall == 1) && (trim($address) != "") && (trim($additional_address) != "")) 
+	{ $address .= ", "; }
+      $address .= $additional_address;
+      trackers_mail_followup($new_item_id, $address, false, false, $reassign_change_artifact);
+      
+
+      # If we get here, assume everything went properly
+      return true;
     }
 
+  return false;
 }
 
 function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
@@ -2039,9 +2115,10 @@ function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
 function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 {
 
-  #we dont force them to be logged in to submit a bug
+  # we dont force them to be logged in to submit a bug
+  unset($ip);
   if (!user_isloggedin())
-    { $user=100; }
+    { $user = 100; }
   else
     { $user=user_getid(); }
 
@@ -2135,11 +2212,13 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 	}
       else if (trackers_data_is_date_field($field))
 	{
-	  # if it's a date we must convert the format to unix time
+	  # if it is a date we must convert the format to unix time
 	  list($value,$ok) = utils_date_to_unixtime($value);
 	}
-
-      $vfl_cols .= ','.$field;
+      
+      # Escape fields name with ` ` just in case (with MySQL 5, plenty 
+      # are reserved)
+      $vfl_cols .= ',`'.$field.'`';
       $vfl_values .= ',\''.$value.'\'';
 
       # Keep track of the change:
@@ -2148,6 +2227,9 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
       $changes[$field]['add']=
       trackers_field_display($field,$group_id,$value,false,false,true,true);
 
+      $changes[$field]['del-val']= $old_value;
+      $changes[$field]['add-val']= $value;
+
       # Register transition id
       $field_transition_accepted[] = $field_transition_id;
 
@@ -2156,20 +2238,31 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
         { $extra_addresses .= $field_transition_cc; }
     }
 
-  # Add all special fields that were not handled in the previous block
-  $fixed_cols = 'close_date,group_id,submitted_by,date,summary,details';
-  # FIXME: Make an exception for the cookbook, since it currently requires
-  # HTML to be inserted. This is an ugly hack and should be fixed real soon.
-  $sql_details = htmlspecialchars($vfl['details']);
-  if (ARTIFACT == "cookbook")
+  # Get the default spamscore
+  $spamscore = spam_get_user_score($user);
+  if ($spamscore > 4)
     {
-      # FIXME: This makes an XSS attack possible!
-      $sql_details = $vfl['details'];
+      $vfl['summary'] = "[SPAM] ".$vfl['summary'];
     }
-  $fixed_values = "'0','$group_id','$user','".time()."','".
-     htmlspecialchars($vfl['summary'])."','".$sql_details."'";
 
 
+  # Add all special fields that were not handled in the previous block
+  $fixed_cols = 'close_date,group_id,submitted_by,date,summary,details,spamscore';
+  $sql_details = htmlspecialchars($vfl['details']);
+  $fixed_values = "'0','$group_id','$user','".
+    time()."','".
+    htmlspecialchars($vfl['summary'])."','".
+    $sql_details."','".
+    $spamscore."'";
+
+  # If not project member, save the IP
+  if (!member_check(0, $group_id))
+    {  
+      $fixed_cols .= ",ip";
+      $fixed_values .= ",'".$_SERVER['REMOTE_ADDR']."'";
+    }
+
+  # Actually insert the entry
   $sql="INSERT INTO ".ARTIFACT." ($fixed_cols $vfl_cols) VALUES ($fixed_values $vfl_values)";
   $result=db_query($sql);
   $item_id=db_insertid($result);
@@ -2183,6 +2276,19 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
   $item = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;;
   fb(sprintf(_("New item posted (%s)"), $item));
 
+  # Register the spam score
+  spam_set_item_default_score($item_id, 
+			      '0',
+			      ARTIFACT,
+			      $spamscore, 
+			      $user);
+
+  # Add to spamcheck queue if necessary (will temporary set the spamscore to
+  # 5, if necessary)
+  # Useless if already considered to be spam.
+  if ($spamscore < 5)
+    {  spam_add_to_spamcheck_queue($item_id, 0, ARTIFACT, $group_id, $spamscore); }
+
   # If we are on the cookbook, Store related links
   if (ARTIFACT == 'cookbook')
    {
@@ -2193,6 +2299,22 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
   # what already changed and that we wont automatically update
   trackers_transition_update_item($item_id, $field_transition_accepted, $changes);
 
+  # Add the submitter in CC
+  # (currently, no option to avoid this, but we could make this a notif
+  # configuration option, if wanted)
+  if (user_isloggedin())
+    {
+      trackers_add_cc($item_id,
+		      $group_id,
+		      user_getid(),
+		      "-SUB-", 
+		      $changes); # use a flag as comment, because if we 
+		               # translate the string now, people will get
+		               # the translation of the submitter when they
+		               # read the item, not necessarily the one they
+		               # want
+			}
+  
   #now return the trackers_id
   return $item_id;
 }
