@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php 5972 2006-09-26 08:55:00Z yeupou $
+# $Id: show.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -516,27 +516,22 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
   global $sys_datefmt;
   $result=trackers_data_get_history($item_id);
   $rows=db_numrows($result);
-
-  # If no limit is not set, print only 10 latest news items
-  # yeupou--gnu.org 2004-09-17: currently we provide no way to get the
-  # full history. We'll see if users request it.
-  if ($no_limit)
-    {
-      $title = _("History");
-    }
-  else
-    {
-      if ($rows > 15)
-	{ $rows = 15; }
-      $title = sprintf(ngettext("%s latest change", "%s latest changes", $rows), $rows);
-    }
-
-
-  print "\n".'<h3>'.html_anchor($title, "history").'</h3>';
-
+  
   if ($rows > 0)
     {
-
+      
+     # If no limit is not set, print only 25 latest news items
+     # yeupou--gnu.org 2004-09-17: currently we provide no way to get the
+     # full history. We will see if users request it.
+      if (!$no_limit)
+	{
+	  if ($rows > 25)
+	    { $rows = 25; }
+	  
+	  $title = sprintf(ngettext("Follows %s latest change.", "Follow %s latest changes.", $rows), $rows);
+	  print "\n".'<p>'.$title.'</p>';
+	}    
+      
       $title_arr=array();
       $title_arr[]=_("Date");
       $title_arr[]=_("Changed By");
@@ -620,7 +615,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 	  else
 	    {
 	      # It's a text zone then display directly
- 	      print $value_id;
+ 	      print markup_basic($value_id);
 	    }
 
            print '</td><td class="smaller" align="center"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="=>" /></td><td class="smaller" align="left">';
@@ -638,7 +633,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 	  else
 	    {
 	      # It's a text zone then display directly
-	      print $new_value_id;
+	      print markup_basic($new_value_id);
 	    }
 	  print '</td>';
 
@@ -852,7 +847,7 @@ function show_dependent_item ($item_id, $dependson=0)
       
   # Add links to make digests
   reset($artifacts);
-  print '<p><span class="preinput">'._("Digest:").'</span><br />&nbsp;&nbsp;&nbsp;';
+  print '<p class="noprint"><span class="preinput">'._("Digest:").'</span><br />&nbsp;&nbsp;&nbsp;';
   unset($content);
   while (list(, $tracker) = each($artifacts))
     {
