@@ -2,10 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: transition.php 4905 2005-11-11 10:55:31Z yeupou $
+# $Id: transition.php 5826 2006-09-18 08:03:37Z yeupou $
 #
-#  Copyright 2004-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2004-2006 (c) Yves Perrin <yves.perrin--cern.ch>
+#                          Mathieu Roy <yeupou---gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -123,7 +123,7 @@ function trackers_transition_update_item ($item_id, $transition_id_array, $chang
 {
   # Array in which we ll store field to updates
   $toupdate = array();
-
+  
   # Extract transitions updates
   if (is_array($transition_id_array))
     {
@@ -173,7 +173,12 @@ function trackers_transition_update_item ($item_id, $transition_id_array, $chang
 					'transition-other-field-update',
 					$value,
 					$item_id);
-	      fb(sprintf(_("Automatic update of %s due to transitions settings"),trackers_data_get_label($field)));
+	      # Put some feedback: do not mention internal fields like
+	      # 'closed on'
+	      if ($field != 'close_date')
+		{
+		  fb(sprintf(_("Automatic update of %s due to transitions settings"),trackers_data_get_label($field)));
+		}
 	      $upd_list .= "$field='$value',";
 	      $exists = 1;
 	    }
