@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: votes.php 4993 2005-11-17 15:13:57Z yeupou $
+# $Id: votes.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -73,7 +73,7 @@ function trackers_votes_update ($item_id, $group_id=0, $new_vote, $tracker=0)
       return false;
     }
 
-  # If the tracker is undefined, use the constant
+  # If the tracker is undefined, use the constant,
   if (!$tracker)
     {
       $tracker = ARTIFACT;
@@ -137,14 +137,16 @@ function trackers_votes_update ($item_id, $group_id=0, $new_vote, $tracker=0)
 	    "(user_id,tracker,item_id,howmuch) ".
 	    "VALUES ('".user_getid()."','".$tracker."','$item_id','$new_vote')";	  
 
-	  # Add in CC
-	  unset($bah); # workaround for stupid function that require a 
-		       # variable to be passed as final argument.
+          # Add in CC
+	  unset($bah); 
+          # workaround for stupid function that require a 
+          # variable to be passed as final argument.
 	  trackers_add_cc($item_id,
 			  $group_id,
 			  user_getname(),
-			  "Voted in favor of this item", # hum, picky to deal
-			  $bah);                        # with, i18n-wise
+			  "Voted in favor of this item",  
+			  $bah);
+
 	}
       else
 	{
