@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php 5988 2006-09-27 16:32:30Z yeupou $
+# $Id: browse.php 6500 2007-04-17 14:22:00Z ype $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -57,11 +57,22 @@ else
   $func = "browse";
 }
 
-
 # Make sure offset is defined and has a correct value
 $offset = sane_get("offset");
 if (!$offset || $offset < 0)
-{ $offset=0; }
+{ $offset = 0; }
+
+# Make sure spamscore has a numeric value between 1 and
+# 20.
+# (we will search for items that have score inferior to $spamscore)
+# Default is five. Under 5, an item is not considered to be spam by the 
+# system. But users can however decide to use a tougher limit
+$spamscore = sane_get("spamscore");
+if (!ctype_digit($spamscore) || $spamscore < 1)
+{ $spamscore = 5; }
+if ($spamscore > 20)
+{ $spamscore = 20; }
+
 
 
 # ==================================================
@@ -189,9 +200,12 @@ if ($morder != '')
 
 # Fill the relevant sql bit to be used later
 # Sensible default case: order by item_id from the recent to the older
-if ($morder == '')
+# (only if not in multiple column sort, otherwise dont mess with it because
+# the first thing to be set will matters a lot)
+if ($morder == '' && !$msort)
 { $morder = "bug_id<"; }
-$order_by = ' ORDER BY '.trackers_criteria_list_to_query($morder);
+if ($morder != '')
+{ $order_by = ' ORDER BY '.trackers_criteria_list_to_query($morder); }
 
 #print "<BR>>DBG Order by = $order_by";
 
@@ -263,6 +277,8 @@ if (!$set)
 		{ $msort = $value_id; }
 	      else if ($field == 'chunksz')
 		{ $chunksz = $value_id; }
+	      else if ($field == 'spamscore')
+		{ $spamscore = $value_id; }
 	      else if ($field == 'report_id')
 		{ $report_id = $value_id; }
 	      else if ($field == 'sumORdet')
@@ -339,6 +355,7 @@ else if ($set=='custom')
   $pref_stg .= '&amp;advsrch='.$advsrch;
   $pref_stg .= '&amp;msort='.$msort;
   $pref_stg .= '&amp;chunksz='.$chunksz;
+  $pref_stg .= '&amp;spamscore='.$spamscore;
   $pref_stg .= '&amp;report_id='.$report_id;
   $pref_stg .= '&amp;sumORdet='.$sumORdet;
 
@@ -423,6 +440,13 @@ else
   $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
 }
 
+# Take into account the spamscore limit (always shows
+# item posted by the logged in user)
+unset($spamscore_additional);
+if (user_getid() != 100)
+{ $spamscore_additional = ' OR submitted_by='.user_getid(); }
+$where .= 'AND ('.ARTIFACT.'.spamscore < '.$spamscore.$spamscore_additional.') ';
+
 # If the user asked for more than 150 items to be shown but is not in printer
 # mode, restrict arbitrarily to 150: 
 # It would be too heavy on the database if this was done very frequently
@@ -744,85 +768,54 @@ while ($field = trackers_list_all_fields(cmp_place_result))
 
 }
 
+if ($history_search) {
+  list($unix_history_date,$ok) = utils_date_to_unixtime($history_date);
+  if ($history_event == "modified") {
+    $from = $from.', '.ARTIFACT.'_history ';
+    $where = $where.'AND '.ARTIFACT.'_history.bug_id = '.ARTIFACT.'.bug_id ';
+    $where .= ' AND '.ARTIFACT.'_history.date >= '.$unix_history_date.' ';
+    if ($history_field != '0') {
+      $where .= ' AND '.ARTIFACT."_history.field_name = '".$history_field."' ";
+    }
+  } else {
+    $from = $from.' LEFT JOIN '.ARTIFACT.'_history ON (('.ARTIFACT.'_history.bug_id = '.ARTIFACT.'.bug_id ) AND ('.ARTIFACT.'_history.date >= '.$unix_history_date.') ';
+    if ($history_field != '0') {
+      $from .= 'AND ('.ARTIFACT."_history.field_name = '".$history_field."')) ";
+    } else {
+      $from .= ') ';
+    }
+    $where .= ' AND '.ARTIFACT.'_history.bug_id IS NULL';
+  }
+}
+
 /* ==================================================
     Run 2 queries : one to count the total number of results, and the second
     one with the LIMIT argument. It is faster than selecting all
     rows (without LIMIT) because when the number of bugs is large it takes
-    time to transfer all the results from the server to the client. It is also faster
-    than using the SQL_CALC_FOUND_ROWS/FOUND_ROWS() capabilities of
-    MySQL
+    time to transfer all the results from the server to the client.
+    It is also faster than using the SQL_CALC_FOUND_ROWS/FOUND_ROWS()
+    capabilities of MySQL
   ================================================== */
+
 $sql_count = "$select_count $from $where";
 $result_count = db_query($sql_count);
 $totalrows = db_result($result_count,0,'count');
 
 $sql = "$select $from $where $order_by $limit";
 
-# If additional constraint history_event is modified, this result will be
-# replaced, and so we dont have to run this sql
-if (!$history_search || $history_event != "modified") 
-{
-  $result = db_query($sql);
-}
+## print "SQL=".$sql."\n";
 
-# Additional constraint
-if ($history_search) 
-{
-  list($unix_history_date,$ok) = utils_date_to_unixtime($history_date);
-
-  # Do 2nd sql query (on history) as long as MINUS is not supported by mysql
-  $select_hist = $select;
-  $from_hist = $from.', '.ARTIFACT.'_history ';
-  $where_hist = $where.'AND '.ARTIFACT.'_history.bug_id = '.ARTIFACT.'.bug_id ';
-  $where_hist .= ' AND '.ARTIFACT.'_history.date >= '.$unix_history_date.' ';
-  if ($history_field != '0') 
-    {
-      $where_hist .= 'AND '.ARTIFACT."_history.field_name = '".$history_field."' ";
-    }
-  $sql_history = "$select_hist $from_hist $where_hist $order_by $limit";
-  $result_history = db_query($sql_history);
-
-  # If the even is "modified", we replace the original sql results.
-  # Otherwise, we build up a list of result to substract
-  if ($history_event == "modified")
-    {
-      $result = $result_history;
-      $totalrows = db_numrows($result);
-    }
-  else
-    {
-      $rows_history = db_numrows($result_history);
-      $history_arr = array();
-      
-      for ($i=0; $i < $rows_history; $i++) 
-	{
-          # Store the entry to be removed later
-	  $hist_bug_id = db_result($result_history, $i, 'bug_id');
-	  $history_arr[$hist_bug_id] = 1;
-	}
-    }
-}
+$result = db_query($sql);
 
 # Build the array that will be given to the function that make the item
 # list. We cannot simply return the SQL results, since we have to remove
-# some entries from the list first:
-#      - private items if necessary
-#      - items depending on the additional constraint
-#
-# $totalrows must be set accordingly
+# private items if necessary and set $totalrows accordingly
 $result_array = array();
 while ($thisarray = db_fetch_array($result))
 {
   # Get the id
   $thisitem_id = $thisarray['bug_id'];
 
-  # Check if we must ignore it due to history additional constraint
-  if ($history_arr[$thisitem_id])
-    { 
-      $totalrows--;
-      continue; 
-    }  
-
   # Do not show private item, apart to technician level members
   # and submitter
   if ($thisarray["privacy"] == "2" &&
@@ -1105,11 +1098,12 @@ if (!$sober)
     {
       # I18N
       # %s in this message is an input field, so it is impossible to use ngettext.
-      $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), 
-					     '<input type="text" name="chunksz" size="3" maxlength="5" value="'.$wanted_chunksz.'" />');
+      $form .= '<p class="smaller">'.sprintf(_("Show: %s items at once ; items with a spam score lower than %s."), 
+					     form_input("text", "chunksz", $wanted_chunksz, 'size="3" maxlength="5"'),
+					     form_input("text", "spamscore", $spamscore, 'size="3" maxlength="2"'));
       if ($wanted_chunksz != $chunksz)
 	{
-          # No use of ngettext as $chunkz will never be below 10, otherwise
+          # No use of ngettext as $chunksz will never be below 10, otherwise
 	  # it would mean that Savane would be modified to never list more
           # than 10 items at once, which is almost nothing.
 	  $form .= ' <span class="warn">'.sprintf(_("Warning: only %s items can be shown at once, unless using Printer Version."), $chunksz).'</span>';
@@ -1119,7 +1113,7 @@ if (!$sober)
     }
   else
     {
-      $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), $chunksz).'</p>';
+      $form .= '<p class="smaller">'.sprintf(_("Show: %s items at once ; items with a spam score lower than %s."), $chunksz, $spamscore).'</p>';
     }
 }
 
