@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php 5945 2006-09-22 12:30:18Z yeupou $
+# $Id: mod.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -128,7 +128,7 @@ if (db_numrows($result) > 0)
 
 # ################################ Start the form
 
-  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em>:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
 
   print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
   print form_input("hidden", "func", "postmoditem");
@@ -176,6 +176,12 @@ if (db_numrows($result) > 0)
 
   # Now display the variable part of the field list (depend on the project)
 
+  # some fields must be displayed differently according to the user role
+  $is_manager = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'3');
+
+  # Variables that will be used afterwards
+  unset($item_assigned_to, $item_discussion_lock);
+
   # $i is used to count the number of field
   # $j is used to select the appropriate background color
   $i=0;
@@ -183,260 +189,310 @@ if (db_numrows($result) > 0)
 
   while ($field_name = trackers_list_all_fields())
     {
-      # if the field is a special field (except summary and details)
-      # or if not used by this project  then skip it.
-      if ((!trackers_data_is_special($field_name) || $field_name=='summary' || $field_name=='details') &&
-	  trackers_data_is_used($field_name))
-	{
-
-          # if the submitter was anonymous, print the originator email field
-	  if ($field_name != 'originator_email' ||
-	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
+      # If the field is not used by the project, skip it
+      if (!trackers_data_is_used($field_name))
+	{ continue ; }
+      
+      # if the field is a special field (not summary) then skip it
+      if (trackers_data_is_special($field_name) &&
+	  $field_name != 'summary')
+	{ 
+	  # If we are on the cookbook, details (a special field) must be
+	  # allowed too
+	  if (ARTIFACT == 'cookbook' && $field_name == 'details')
 	    {
-
-             # display the bug field
-             # if field size is greatest than max_size chars then force it to
-             # appear alone on a new line or it wont fit in the page
-
-             # Look for the field value in the database only if we missing
-             # its values. If we already have a value, we are probably in
-             # step 2 of a search on item/group (dependency, reassignation).
-
-             # If nocache is set, we were explicetely asked to rely only
-             # on database content
-	     # If we rely on submitted by form content, due to magic_quotes,
-	     # we need to run both stripslashes and htmlspecialchars
-	      if (!$$field_name || $nocache)
-		{ $field_value = db_result($result,0,$field_name); }
-	      else
-		{ $field_value = htmlspecialchars(stripslashes($$field_name)); }
-	      # On the cookbook, the recipe text must allow to see html
-	      # special chars as they were typed.
-	      if (ARTIFACT == "cookbook" && $field_name == 'details')
-		{
-		  $field_value = htmlspecialchars($field_value);
-		}
-
-	      list($sz,) = trackers_data_get_display_size($field_name);
-	      $label = trackers_field_label_display($field_name,$group_id,false,false);
-
-              # Save the assigned to value for later
-	      if ($field_name == 'assigned_to')
-		{ $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
-		}
-
-               # original submission field must be displayed read-only,
-	       # (unless we are on the cookbook)
-               # assigned_to, status_id and priority too, for technicians
-               # (if super_user, do nothing)
-	      if (!user_is_super_user())
-		{ $mbcheck = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1); }
-
-	      if (($field_name =='details' && ARTIFACT != "cookbook") ||
-		  ($mbcheck && $field_name == 'status_id') ||
-		  ($mbcheck && $field_name == 'assigned_to') ||
-		  ($mbcheck && $field_name == 'priority') ||
-		  ($mbcheck && $field_name == 'originator_email'))
-		{
-		  dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
-		  $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true));
-
-		  # Details need a specific div
-		  if ($field_name == 'details')
-		    {
-		      $value = '<div class="trackersoriginalsubmission">'.$value.'</div>';
-		    }
-
-		}
-	      else
-		{
-		  $value = trackers_field_display($field_name,$group_id,$field_value,false,false,$printer,false,false,_("None"),false,_("Any"),true);
-		}
-
-	      # check if the field is mandatory
-	      unset($star);
-	      $mandatory_flag = trackers_data_mandatory_flag($field_name);
-	      if ($mandatory_flag == 3 ||
-		  ($mandatory_flag == 0 &&
-		   trackers_check_is_shown_to_submitter($field_name, $group_id, db_result($result,0,'submitted_by'))))
-
-		{
-		  $star = '<span class="warn"> *</span>';
-		}
-
-              # Fields colors
-	      unset($field_class, $row_class);
-	      if ($j % 2 && $field_name != 'details')
-		{
-		  # We keep the original submission with the default
-		  # background color, for lisibility sake
-		  #
-		  # We also use the boxitem background color only one time
-		  # out of two, to keep the page light
-		  $row_class = ' class="'.utils_altrow($j+1).'"';
-		}
-
-	      # If we are working on the cookbook, present checkboxes to
-	      # defines context before the summary line;
-	      if (CONTEXT == 'cookbook' && $field_name == 'summary')
-		{
-		  cookbook_print_form();
-		}
-
-              # We highlight fields that were not properly/completely
-	      # filled.
-	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
-		{
-		  $field_class = ' class="highlight"';
-		}
-
-	      if ($sz > $max_size)
-		{
-		  # Field getting one line for itself
-
-                  # Each time prepare the change of the background color
-		  $j++;
-
-		  print "\n<tr".$row_class.">".
-		    '<td valign="middle" '.$field_class.' width="15%">'.$label.$star.'</td>'.
-		    '<td valign="middle" '.$field_class.' colspan="'.(2*$fields_per_line-1).'" width="75%">'.
-		    $value.'</td>'.
-		    "\n</tr>";
-		  $i=0;
-		}
-	      else
-		{
-		  # Field getting half of a line for itself
-
-
-		  if (!($i % $fields_per_line))
-		    {
-		      # Every one out of two, prepare the background color change.
-   		      # We do that at this moment because we cannot be sure
- 		      # there will be another field on this line.
-		      $j++;
-		    }
-
-		  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
-		  print '<td valign="middle"'.$field_class.' width="15%">'.$label.$star.'</td><td valign="middle"'.$field_class.' width="35%">'.$value.'</td>';
-		  $i++;
-		  print ($i % $fields_per_line ? '':"\n</tr>");
-		}
+	      # ok
+	    }
+	  else
+	    {
+	      continue; 
 	    }
 	}
-    }
+      
+      #  print the originator email field only if the submitted was anonymous
+      if ($field_name == 'originator_email' && 
+	  db_result($result,0,'submitted_by') != '100')
+	{ continue; }
 
+      # display the bug field
+      # if field size is greatest than max_size chars then force it to
+      # appear alone on a new line or it wont fit in the page
+
+      # Look for the field value in the database only if we missing
+      # its values. If we already have a value, we are probably in
+      # step 2 of a search on item/group (dependency, reassignation).
+
+      # If nocache is set, we were explicetely asked to rely only
+      # on database content
+      # If we rely on submitted by form content, due to magic_quotes,
+      # we need to run both stripslashes and htmlspecialchars
+      if (!$$field_name || $nocache)
+	{ $field_value = db_result($result,0,$field_name); }
+      else
+	{ $field_value = htmlspecialchars(stripslashes($$field_name)); }
+      list($sz,) = trackers_data_get_display_size($field_name);
+      $label = trackers_field_label_display($field_name,$group_id,false,false);
+      
+      # Save the assigned to value for later
+      if ($field_name == 'assigned_to')
+	{ $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
+	}
+            
+      # Discussion lock is shown only to at least managers
+      if ($field_name == 'discussion_lock')
+	{ 
+	  # Save for later
+	  $item_discussion_lock = db_result($result,0,$field_name);
+	  if (!$is_manager)
+	    { continue; }
+	}
+
+      # some fields must be displayed read-only,
+      # assigned_to, status_id and priority too, for technicians
+      # (if super_user, do nothing)
+      if (!$is_manager && 
+	  ($field_name == 'status_id' ||
+	   $field_name == 'assigned_to' ||
+	   $field_name == 'priority' ||
+	   $field_name == 'originator_email'))
+	{	  
+	  $value = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
+	  if ($field_name == 'originator_email')
+	    {
+	      $value = utils_email_basic($value);
+	    }
+	  
+	}
+      else
+	{
+	  $value = trackers_field_display($field_name,$group_id,$field_value,false,false,$printer,false,false,_("None"),false,_("Any"),true);
+	}
+      
+      # check if the field is mandatory
+      unset($star);
+      $mandatory_flag = trackers_data_mandatory_flag($field_name);
+      if ($mandatory_flag == 3 ||
+	  ($mandatory_flag == 0 &&
+	   trackers_check_is_shown_to_submitter($field_name, $group_id, db_result($result,0,'submitted_by'))))
+	
+	{
+	  $star = '<span class="warn"> *</span>';
+	}
+      
+      # Fields colors
+      unset($field_class, $row_class);
+      if ($j % 2 && $field_name != 'details')
+	{
+          # We keep the original submission with the default
+	  # background color, for lisibility sake
+	  #
+	  # We also use the boxitem background color only one time
+          # out of two, to keep the page light
+	  $row_class = ' class="'.utils_altrow($j+1).'"';
+	}
+      
+      # If we are working on the cookbook, present checkboxes to
+      # defines context before the summary line;
+      if (CONTEXT == 'cookbook' && $field_name == 'summary')
+	{
+	  cookbook_print_form();
+	}
+      
+      # We highlight fields that were not properly/completely
+      # filled.
+      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
+	{
+	  $field_class = ' class="highlight"';
+	}
+      
+      if ($sz > $max_size)
+	{
+	  # Field getting one line for itself
+
+          # Each time prepare the change of the background color
+	  $j++;
+	  
+	  print "\n<tr".$row_class.">".
+	    '<td valign="middle" '.$field_class.' width="15%">'.$label.$star.'</td>'.
+	    '<td valign="middle" '.$field_class.' colspan="'.(2*$fields_per_line-1).'" width="75%">'.
+	    $value.'</td>'.
+	    "\n</tr>";
+	  $i=0;
+	}
+      else
+	{
+          # Field getting half of a line for itself
+	  if (!($i % $fields_per_line))
+	    {
+              # Every one out of two, prepare the background color change.
+              # We do that at this moment because we cannot be sure
+ 	      # there will be another field on this line.
+	      $j++;
+	    }
+
+	  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
+	  print '<td valign="middle"'.$field_class.' width="15%">'.$label.$star.'</td><td valign="middle"'.$field_class.' width="35%">'.$value.'</td>';
+	  $i++;
+	  print ($i % $fields_per_line ? '':"\n</tr>");
+	}
+    }
+  
+  
   print '</table>';
-  print '<p class="warn"><span class="smaller">* '._("Mandatory Fields").'</span></p>';
-  print '<p>&nbsp;</p>';
+  print '<div class="warn"><span class="smaller">* '._("Mandatory Fields").'</span></div>';
 
-# ################################ Shortcuts
 
-  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> details:"), $item_link).'</h2>';
-  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';
-  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
-  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
-  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
-  if (trackers_data_is_used("vote"))
+# ############################### Determine which subpart must be deployed
+  $is_deployed = array();
+
+  # Default picks
+  $is_deployed["postcomment"] = false;
+  $is_deployed["discussion"] = true;
+  $is_deployed["attached"] = true;
+  $is_deployed["dependencies"] = true;
+  $is_deployed["cc"] = false;
+  $is_deployed["votes"] = false;
+  $is_deployed["reassign"] = false;
+
+  # In printer mode, deploy everything by default: assume that people default
+  # printout should contain all necessary info (note that history is excluded)
+  if (sane_all("printer"))
     {
-      print '&nbsp;&nbsp;- <a href="#votes">'._("Votes").'</a><br />';
+      reset($is_deployed);
+      while (list($entry,) = each($is_deployed))
+	{ $is_deployed[$entry] = true; }
     }
-  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3') && ARTIFACT != "cookbook")
+  
+  # If at the second step of any too-step activity (add deps, reassign, 
+  # multiple canned answer), deploy only the relevant:
+  # firdt set them all to false without question and then set to true only
+  # the relevant
+  if ($depends_search || 
+      $canned_response == "!multiple!" || 
+      $reassign_change_project_search)
     {
-      print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br />';
+      reset($is_deployed);
+      while (list($entry,) = each($is_deployed))
+	{ $is_deployed[$entry] = false; }
+
+      if ($depends_search)
+	{ $is_deployed["dependencies"] = true; }
+      if ($canned_response == "!multiple!")
+	{ $is_deployed["postcomment"] = true; }
+      if ($reassign_change_project_search)
+	{ $is_deployed["reassign"] = true; }
     }
 
-  print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
-  print '<p>&nbsp;</p></div>';
+# ################################ Post a comment
 
-# ################################ Comments
+  # For now hidden by default, assuming that people first read comments,
+  # then post comment.
+  # The bad side is the fact that they are forced to click at least one.
+  # The good thing is they do not have to scroll when starting.
+  # There is one more click but people feel more in control (well, at least
+  # the one that were vocal about Savane UI design)
+  print '<span class="noprint">';
+  print html_hidsubpart_header("postcomment", 
+			       _("Post a Comment"));
 
-  print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
-  print '<p class="noprint">';
-  printf (_("(Note: you can add pointers to other items by typing %s where %s is one of %s and %s is the item id number.)"),
-	  "<em>artifact #nnn</em>",
-	  "<em>artifact</em>",
-	  "<em>support, bug, task, recipe, patch, file</em>",
-	  "<em>nnn</em>");
-
-  print '<p class="noprint"><span class="preinput"> '._("Add a New Comment:").'</span><br />
-      &nbsp;&nbsp;&nbsp;';
+  # The discussion lock will not prevent technicians and manager to comment
+  # The point is too filter spams and to allow to stop flamewars, but
+  # managers and technician are expected to be serious enough
+  
+  print '<p class="noprint"><span class="preinput"> '.sprintf(_("Add a New Comment %s:"), markup_info("rich")).'</span><br /> &nbsp;&nbsp;&nbsp;';
   print trackers_field_textarea('comment',  htmlspecialchars(stripslashes($comment)));
   print '</p>';
-
+  
   print '<p class="noprint"><span class="preinput">';
-  print _("Comment Type:").'</span><br />&nbsp;&nbsp;&nbsp;';
+  print _("Comment Type & Canned Response:").'</span><br />&nbsp;&nbsp;&nbsp;';
   print trackers_field_box('comment_type_id',$comment_type_id,$group_id,'',true,'None');
-
-
-  print '<br /><span class="preinput">'._("Use a Canned Response:").'</span><br />&nbsp;&nbsp;&nbsp;';
-
+    
+  print '&nbsp;&nbsp;&nbsp;';
+  
   if ($canned_response == "!multiple!")
     {
-
+      
       $result_canned = trackers_data_get_canned_responses($group_id);
       if (db_numrows($result_canned) > 0)
 	{
-
+	  print '<div>';
+	  
 	  while ($canned = db_fetch_array($result_canned))
 	    {
-
-              print form_input("checkbox", "canned_response[]", $canned['bug_canned_id']).' '.$canned['title'];
-              print '<br />&nbsp;&nbsp;&nbsp;';
-
+	      print '&nbsp;&nbsp;&nbsp;';
+	      print form_input("checkbox", "canned_response[]", $canned['bug_canned_id']).' '.$canned['title'];
+	      print '<br />';
+	      
 	    }
+	  print '</div>';
 	}
       else
 	{
 	  print '<span class="warn">'._("Strangely enough, there is no canned response available.").'</span>';
 	}
-
+      
+      
     }
   else
     {
-
+      
       print trackers_canned_response_box ($group_id,'canned_response');
       print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&amp;create_canned=1">('._("Or define a new Canned Response").')</a>';
-
+      
     }
-  print '<br /><span class="preinput">'._("Previous Comment Style:").'</span><br />&nbsp;&nbsp;&nbsp;';
-  if ($quotation_style != "quoted")
+
+  print '</p>';
+
+  if ($item_discussion_lock)
     {
-      print form_submit(_("Quoted, ready to be copied/pasted into your new comment"), "change_quotation_style");
-    }
-  else
-    {
-      print form_submit(_("Verbatim, unmodified"), "change_quotation_style");
-
+      print '<p class="warn">'._("Discussion locked!").' '._("Your privileges however allow to override the lock."); 
+      print '</p>';
     }
 
+  print '<p>&nbsp;</p>';
+  print html_hidsubpart_footer();
+  print '</span>';
 
+# ################################ Read Comments
 
-  print '</p>&nbsp;<p>';
-
+  print html_hidsubpart_header("discussion",
+			       _("Discussion"));
+ 
   print show_item_details($item_id,$group_id,0,$item_assigned_to,$quotation_style);
 
-  print '</p><p>&nbsp;</p>';
+  print '<p>&nbsp;</p>';
+  print html_hidsubpart_footer();
 
 # ################################ Attached Files
 
-  print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
+  # deployed by default, important item info
+  print html_hidsubpart_header("attached", 
+			       _("Attached Files"));
+
   print '<p class="noprint">';
-  print sprintf(_("(Note: file size limit is set to %s kB, after insertion of the required escape characters.)"), $GLOBALS['sys_upload_max']);
-  print '</p><p class="noprint"><span class="preinput"> '._("Attach File:").'</span><br />
-      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40" />
+  print sprintf(_("(Note: upload size limit is set to %s kB, after insertion of the required escape characters.)"), $GLOBALS['sys_upload_max']);
+
+  print '</p><p class="noprint"><span class="preinput"> '._("Attach File(s):").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file1" size="10" /> <input type="file" name="input_file2" size="10" />
       <br />
-      <span class="preinput">'._("File Description:").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file3" size="10" /> <input type="file" name="input_file4" size="10" />
+      <br />
+      <span class="preinput">'._("Comment:").'</span><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255" />
       </p><p>';
 
   show_item_attached_files($item_id,$group_id);
 
   print '</p><p>&nbsp;</p>';
+  print html_hidsubpart_footer();
+
 
 # ################################ Dependencies
 
-  print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
+  # deployed by default, important item info
+  print html_hidsubpart_header("dependencies", 
+			       _("Dependencies"));
+
   print '<p class="noprint"><span class="preinput">';
   if (!$depends_search)
     { print _("Search an item (to fill a dependency against):"); }
@@ -577,22 +633,24 @@ if (db_numrows($result) > 0)
   print show_dependent_item($item_id);
 
   print '</p><p>&nbsp;</p>';
+  print html_hidsubpart_footer();
 
 # ################################ Mail notification
 
-  print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
+  print html_hidsubpart_header("cc", 
+			       _("Mail Notification Carbon-Copy List"));
   print '<p class="noprint">';
   printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
 
   print '</p><p class="noprint"><span class="preinput">'
-    ._("Add Email Addresses (comma as separator):").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'" />&nbsp;&nbsp;&nbsp;
+    ._("Add Email Addresses (comma as separator):").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.htmlspecialchars(stripslashes($add_cc)).'" />&nbsp;&nbsp;&nbsp;
         <br />
         <span class="preinput">'
-    ._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'" />';
+    ._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.htmlspecialchars(stripslashes($cc_comment)).'" />';
   print '<p></p>';
   show_item_cc_list($item_id, $group_id);
-
   print '<p>&nbsp;</p>';
+  print html_hidsubpart_footer();
 
 # ################################ Votes
 
@@ -605,24 +663,29 @@ if (db_numrows($result) > 0)
 
 # ATM, the mod page is only for technicians/manager. They always have
 # the right to vote, as they are project member anyway.
-      print '<h3>'.html_anchor(_("Votes"), "votes").'</h3>';
+      print html_hidsubpart_header("votes", 
+				   _("Votes"));
       print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independently of the priority of the item set by tracker managers.").'</p><p class="noprint">';
 
 # Show how many vote he already gave and allows to remove or give more
 # votes.
 # The number of remaining points must be 100 - others votes
-      print '<span class="preinput">'._("Your vote:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
+      print '<span class="preinput">'._("Your vote:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.htmlspecialchars(stripslashes($new_vote)).'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
       print '</p>';
       print '<p>&nbsp;</p>';
+      print html_hidsubpart_footer();
     }
 
 # ################################ Reassign an item, if manager of the tracker
 # Not possible on the cookbook manager, cookbook entries are too specific
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3') && ARTIFACT != "cookbook")
     {
-      print '<h3 class="noprint">'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
+      # no point in having this part printable
+      print '<span class="noprint">';
+      print html_hidsubpart_header("reassign",
+				   _("Reassign this item"));
 
-      print '<p class="noprint"><span class="preinput">'
+      print '<span class="preinput">'
 	._("Move to the:").'</span><br />&nbsp;&nbsp;&nbsp;';
 
       function specific_reassign_artifact ($art, $content)
@@ -639,7 +702,7 @@ if (db_numrows($result) > 0)
       specific_reassign_artifact("task", _("Task Tracker"));
       specific_reassign_artifact("patch", _("Patch Tracker"));
       print '</select>';
-
+      
       print '<br /><br />
         <span class="preinput">';
 
@@ -702,6 +765,9 @@ if (db_numrows($result) > 0)
 	    }
 
 	}
+      
+      print html_hidsubpart_footer();
+      print '</span>';
     }
 
 
@@ -714,10 +780,11 @@ if (db_numrows($result) > 0)
 
 
 # ################################ History
-# May require in the future to think about only showing recent changes.
 
   print '<p>&nbsp;</p><p>&nbsp;</p>';
-  print show_item_history($item_id,$group_id);
+  print html_hidsubpart_header("history", _("History"));
+  show_item_history($item_id,$group_id);
+  print html_hidsubpart_footer();
 
 }
 
