@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod_filters.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: mod_filters.php 5565 2006-08-14 09:18:01Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
@@ -24,7 +24,7 @@
 
 exit;
 
-function show_filters ($group_id) 
+function show_filters ($group_id)
 {
 	/*
 		The goal here is to show any existing bug filters for this user/group combo.
@@ -50,14 +50,15 @@ function show_filters ($group_id)
 			?>">
 			<TR class="<?php echo utils_get_alt_row_color($i); ?>">
 				<TD>
-					<FONT SIZE="-1"><INPUT TYPE="SUBMIT" NAME="delete_filter" VALUE="Delete"><BR>
+					<span class="smaller"><INPUT TYPE="SUBMIT" NAME="delete_filter" VALUE="Delete"><BR>
 					<INPUT TYPE="SUBMIT" NAME="submit" VALUE="Modify/Activate">
+                                        </span>
 				</TD>
-				<TD NOWRAP><FONT SIZE="-1">SELECT * FROM bug WHERE<BR>bug.group_id='<?php echo $group_id; ?>' AND (</TD>
-				<TD NOWRAP><FONT SIZE="-1"><INPUT TYPE="TEXT" SIZE="60" MAXLENGTH="250" NAME="sql_clause" VALUE="<?php
+				<TD NOWRAP><span class="smaller">SELECT * FROM bug WHERE<BR>bug.group_id='<?php echo $group_id; ?>' AND (</span></TD>
+				<TD NOWRAP><span class="smaller"><INPUT TYPE="TEXT" SIZE="60" MAXLENGTH="250" NAME="sql_clause" VALUE="<?php
 						echo stripslashes(db_result($result,$i,"sql_clause"));
-					?>"></TD>
-				<TD NOWRAP><FONT SIZE="-1">) LIMIT 0,50</TD>
+					?>"></span></TD>
+				<TD NOWRAP><span class="smaller">) LIMIT 0,50</span></TD>
 			</TR></FORM>
 			<?php
 
@@ -74,10 +75,10 @@ function show_filters ($group_id)
 	<INPUT TYPE="HIDDEN" NAME="group_id" VALUE="<?php echo $group_id; ?>">
 	<INPUT TYPE="HIDDEN" NAME="subfunc" VALUE="add">
 	<TR class="<?php echo utils_get_alt_row_color($i); ?>">
-		<TD><FONT SIZE="-1"><INPUT TYPE="SUBMIT" NAME="SUBMIT" VALUE="Add"></TD>
-		<TD NOWRAP><FONT SIZE="-1">SELECT * FROM bug WHERE<BR>bug.group_id='<?php echo $group_id; ?>' AND (</TD>
-		<TD NOWRAP><FONT SIZE="-1"><INPUT TYPE="TEXT" SIZE="60" MAXLENGTH="250" NAME="sql_clause" VALUE="bug.status_id IN (1,2,3) OR bug.severity > 0 OR bug.bug_group_id IN (1,2,3,4) OR bug.resolution_id IN (1,2,3) OR bug.assigned_to IN (1,2,3,4,5,6) OR bug.category_id IN (1,2,3)"></TD>
-		<TD NOWRAP><FONT SIZE="-1">) LIMIT 0,50</TD>
+		<TD><span class="smaller"><INPUT TYPE="SUBMIT" NAME="SUBMIT" VALUE="Add"></span></TD>
+		<TD NOWRAP><span class="smaller">SELECT * FROM bug WHERE<BR>bug.group_id='<?php echo $group_id; ?>' AND (</span></TD>
+		<TD NOWRAP><span class="smaller"><INPUT TYPE="TEXT" SIZE="60" MAXLENGTH="250" NAME="sql_clause" VALUE="bug.status_id IN (1,2,3) OR bug.severity > 0 OR bug.bug_group_id IN (1,2,3,4) OR bug.resolution_id IN (1,2,3) OR bug.assigned_to IN (1,2,3,4,5,6) OR bug.category_id IN (1,2,3)"></span></TD>
+		<TD NOWRAP><span class="smaller">) LIMIT 0,50</span></TD>
 	</TR></FORM>
 	</TABLE>
 	<P>
@@ -97,7 +98,7 @@ bug_header(array ('title'=>'Create a Personal Filter'));
 if (user_isloggedin()) {
 
 	echo "<H2>Create a personal filter for ".user_getname()."</H2>";
-	echo "<B>Creating or modifying a filter makes it your active filter</B><P>";
+	echo "<strong>Creating or modifying a filter makes it your active filter</strong><P>";
 	echo "Be sure include 'bug.' before each field name, as in the example, as multiple tables are being joined in the query";
 
 	show_filters($group_id);
@@ -121,17 +122,17 @@ if (user_isloggedin()) {
 	<TABLE WIDTH="100%" CELLPADDING="3">
 		<TR>
 			<TD  COLSPAN="3">
-				<B>The following tables show which statuses, technicians, and categories you can include in your filter.
+				<strong>The following tables show which statuses, technicians, and categories you can include in your filter.
 			</TD>
 		</TR>
 		<TR>
-			<TD  VALIGN="TOP"><?php ShowResultSet($result,"Bug Techs for ".group_getname($group_id)); ?></TD>
-			<TD  VALIGN="TOP"><?php ShowResultSet($result2,"Bug Statuses"); ?></TD>
-			<TD  VALIGN="TOP"><?php ShowResultSet($result3,"Bug Categories for ".group_getname($group_id)); ?></TD>
+			<TD  VALIGN="TOP"><?php utils_show_result_set($result,"Bug Techs for ".group_getname($group_id)); ?></TD>
+			<TD  VALIGN="TOP"><?php utils_show_result_set($result2,"Bug Statuses"); ?></TD>
+			<TD  VALIGN="TOP"><?php utils_show_result_set($result3,"Bug Categories for ".group_getname($group_id)); ?></TD>
 		<TR>
 		<TR>
-			<TD  VALIGN="TOP"><?php ShowResultSet($result4,"Bug Resolutions"); ?></TD>
-			<TD  VALIGN="TOP"><?php ShowResultSet($result5,"Bug Groups"); ?></TD>
+			<TD  VALIGN="TOP"><?php utils_show_result_set($result4,"Bug Resolutions"); ?></TD>
+			<TD  VALIGN="TOP"><?php utils_show_result_set($result5,"Bug Groups"); ?></TD>
 			<TD>&nbsp;</TD>
 		</TR>
 	</TABLE>
