@@ -2,12 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user.php 5571 2006-08-14 19:13:27Z toddy $
+# $Id: user.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -243,14 +242,17 @@ function user_getid($username=0)
     }
 }
 
-function user_exists($user_id) 
+function user_exists($user_id, $squad_only=false) 
 {
   $result = user_get_result_set($user_id); 
-  if ($result && db_numrows($result) > 0) {
-    return 1;
-  } else {
-    return 0;
-  }
+  if ($result && db_numrows($result) > 0) 
+    {
+      if (!$squad_only)
+	{ return true; }
+      else if ($squad_only && db_result($result, 0, 'status') == 'SQD')
+	{ return true; }
+    } 
+  return false;
 }
 
 #quick hack - this entire library needs a rewrite similar to groups library
@@ -266,8 +268,11 @@ function user_getrealname($user_id=0, $rfc822_compliant=0)
   return $ret;
 }
 
-function user_getemail($user_id)
+function user_getemail($user_id=0)
 {
+  if (!$user_id)
+    { $user_id = user_getid(); }
+
   $result = user_get_result_set($user_id); 
   if ($result && db_numrows($result) > 0) 
     {
@@ -324,24 +329,24 @@ function user_get_timezone()
 function user_set_preference ($preference_name,$value) 
 {
   global $user_pref;
-  if (user_isloggedin()) {
-    $preference_name=strtolower(trim($preference_name));
-    $result=db_query("UPDATE user_preferences SET preference_value='$value' ".
-		     "WHERE user_id='".user_getid()."' AND preference_name='$preference_name'");
-    if (db_affected_rows($result) < 1) {
-      $result=db_query("INSERT INTO user_preferences (user_id,preference_name,preference_value) ".
-		       "VALUES ('".user_getid()."','$preference_name','$value')");
-    }
-
-    # Update the Preference cache if it was setup by a user_get_preference
-    if (isset($user_pref)) 
-      { $user_pref[$preference_name] = $value; }
-
+  if (user_isloggedin()) 
+    {
+      $preference_name=strtolower(trim($preference_name));
+      $result=db_query("UPDATE user_preferences SET preference_value='$value' ".
+		       "WHERE user_id='".user_getid()."' AND preference_name='$preference_name'");
+      if (db_affected_rows($result) < 1) {
+	$result=db_query("INSERT INTO user_preferences (user_id,preference_name,preference_value) ".
+			 "VALUES ('".user_getid()."','$preference_name','$value')");
+      }
+      
+# Update the Preference cache if it was setup by a user_get_preference
+      if (isset($user_pref)) 
+	{ $user_pref[$preference_name] = $value; }
+      
     return true;
-
-  } else {
-    return false;
-  }
+    
+    } 
+  return false;
 }
 function user_unset_preference ($preference_name) 
 {
@@ -357,6 +362,7 @@ function user_unset_preference ($preference_name)
     dbg("Remove pref $preference_name");
     return true;
   }
+  return false;
 }
 
 
@@ -469,4 +475,69 @@ function user_guess ()
 
 }
 
+# Function that should always be used to remove an user account
+# This function should always be used in a secure context, when user_id
+# is 100% sure.
+# Best is to not to pass the user_id argument unless necessary
+function user_delete ($user_id=false, $confirm_hash=false)
+{
+  if (!$user_id)
+    { $user_id = user_getid(); }
+
+  # Serious deal, serious check of credentials: allowed only to superuser
+  # and owner of the account
+  if (!user_is_super_user() && $user_id != user_getid())
+    {  
+      exit_permission_denied();
+    }
+
+  # If self-destruct, the correct confirm_hash must be provided
+  if (!user_is_super_user())
+    {
+      $confirm_hash = " confirm_hash='$confirm_hash' AND ";
+    }
+  else
+    {
+      unset($confirm_hash);
+    }
+
+
+  $success = db_query("UPDATE user SET "
+		      . "user_pw='*********34344',"
+		      . "realname='-Deleted Account-',"
+		      . "status='S',"
+		      . "email='idontexist@nowhere.net',"
+		      . "confirm_hash='',"
+		      . "authorized_keys='',"
+		      . "people_view_skills='0',"
+		      . "people_resume='',"
+		      . "timezone='GMT',"
+		      . "theme='',"
+		      . "gpg_key='',"
+		      . "email_new='' WHERE "
+		      . "$confirm_hash "
+		      . "user_id='".$user_id."' LIMIT 1");
+
+  # Remove from any groups, if by any chances this was not done before
+  # (normally, an user must quit groups before being allowed to delete his
+  # account)
+  db_query("DELETE FROM user_group WHERE user_id='".$user_id."'");  
+  db_query("DELETE FROM user_squad WHERE user_id='".$user_id."'");
+
+  # Additionally, clean up sessions, remove prefs
+  db_query("DELETE FROM user_bookmarks WHERE user_id='".$user_id."'");  
+  db_query("DELETE FROM user_preferences WHERE user_id='".$user_id."'");
+  db_query("DELETE FROM user_votes WHERE user_id='".$user_id."'");
+  db_query("DELETE FROM session WHERE user_id='".$user_id."'");
+  
+  if ($success)
+    { 
+      fb(_("Account deleted.")); 
+      return true;
+    }
+
+  fb(_("Failed to update the database."), 1); 
+  return false;
+}
+
 ?>
