@@ -2,10 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user_home.php 6020 2006-10-02 07:39:21Z yeupou $
+# $Id: user_home.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2001 (c) Free Software Foundation
 #
 #  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -38,13 +37,27 @@ site_header(array('title'=>sprintf(_("%s Profile"),db_result($res_user, $i, 'rea
 
 # For suspended account, we will print only very basic info:
 # accound id, login + description as deleted account
-$is_suspended = 0;
+$is_suspended = false;
 if (db_result($res_user,0,'status') == 'S')
-{ $is_suspended = 1; }
+{ $is_suspended = true; }
+
+$is_squad = false;
+if (db_result($res_user,0,'status') == 'SQD')
+{ $is_squad = true; }
+
+# For squad account, we will print some specific info
 
 
-print '<p>'.sprintf(_("Follows the Profile of %s."), utils_user_link(db_result($res_user, $i, 'user_name'),db_result($res_user, $i, 'realname'))).'</p>';
 
+print '<p>'.sprintf(_("Follows the Profile of %s."), utils_user_link(db_result($res_user, $i, 'user_name'),db_result($res_user, $i, 'realname')));
+
+if ($is_squad) 
+{
+  print ' '._("It is not a normal user account but a squad: it unites several users as if they were one (notifications, privileges, etc).");
+
+}
+
+print '</p>';
 
 print html_splitpage("start");
 
@@ -87,13 +100,17 @@ if (!$is_suspended)
     { $nogroups = 1; }
 
 
-  print $HTML->box_top(sprintf(_("Open Items submitted by %s"),db_result($res_user,0,'realname')),'',1);
-  # FIXME: News item are missing
+  if (!$is_squad)
+    {
+      # meaningless for squads
+      print $HTML->box_top(sprintf(_("Open Items submitted by %s"),db_result($res_user,0,'realname')),'',1);
+      # FIXME: News item are missing
 
-  my_item_list("submitter", "0", "open", $user_id, true);
-  print $HTML->box_bottom(1);
+      my_item_list("submitter", "0", "open", $user_id, true);
+      print $HTML->box_bottom(1);
 
-  print "<br />\n";
+      print "<br />\n";
+    }
 
   print $HTML->box_top(sprintf(_("Open Items assigned to %s"),db_result($res_user,0,'realname')),'',1);
   # FIXME: News item are missing
@@ -141,12 +158,17 @@ if (db_result($res_user,0,'email_hide') == "1")
 } 
 else 
 {
-  print utils_email(db_result($res_user,0,'email'));
+  print utils_email_basic(db_result($res_user,0,'email'), 1);
 }
 
 print '</a></strong>
 	</td>
-</tr>
+</tr>';
+
+# meaningless for squads
+if (!$is_squad)
+{ 
+  print '
 <tr valign="top">
 	<td>'
     ._("Site Member Since").':
@@ -159,22 +181,26 @@ print '</a></strong>
 	 <td></td>
 	 <td>';
   
-if (db_result($res_user,0,'people_view_skills') != 1) {
-  print _("This user deactivated his/her Resume & Skills").'.';
-} else {
-  print '<a href="'.$GLOBALS['sys_home'].'people/resume.php?user_id='.db_result($res_user,0,'user_id').'"><strong>'._("View Resume & Skills").'</strong></a>';
-}
+  if (db_result($res_user,0,'people_view_skills') != 1) 
+    {
+      print _("This user deactivated his/her Resume & Skills").'.';
+    } 
+  else 
+    {
+      print '<a href="'.$GLOBALS['sys_home'].'people/resume.php?user_id='.db_result($res_user,0,'user_id').'"><strong>'._("View Resume & Skills").'</strong></a>';
+    }
 
-print '
+  print '
 	</td>
 </tr>
 ';
-
-if (db_result($res_user,0,'gpg_key') != "") {
-  print '<tr valign="top"><td></td><td>';
-  print	'<a href="'.$GLOBALS['sys_home'].'people/viewgpg.php?user_id='.db_result($res_user,0,'user_id').'"><strong>'._("Download GPG Key").'</strong></a>';
-  print '</td></tr>';
   
+  if (db_result($res_user,0,'gpg_key') != "") {
+    print '<tr valign="top"><td></td><td>';
+    print	'<a href="'.$GLOBALS['sys_home'].'people/viewgpg.php?user_id='.db_result($res_user,0,'user_id').'"><strong>'._("Download GPG Key").'</strong></a>';
+    print '</td></tr>';
+    
+  }
 }
 
 print '</table>';
@@ -215,16 +241,17 @@ if (!$is_suspended)
 # Alternative sql that do not use group_history, just in case this history
 # would be flawed (history usage has been inconsistent over Savane history)
 $sql_without_history = "SELECT groups.group_name,"
-. "groups.group_id,"
-. "groups.unix_group_name,"
-. "groups.status,"
-. "user_group.admin_flags "
-. "FROM groups,user_group "
-. "WHERE groups.group_id=user_group.group_id "
-. "AND user_group.user_id='".$user_id."' "
-. "AND groups.status='A' "
-. "GROUP BY groups.unix_group_name "
-. "ORDER BY groups.unix_group_name";
+  . "groups.group_id,"
+  . "groups.unix_group_name,"
+  . "groups.status,"
+  . "user_group.admin_flags "
+  . "FROM groups,user_group "
+  . "WHERE groups.group_id=user_group.group_id "
+  . "AND user_group.user_id='".$user_id."' "
+  . "AND groups.status='A' "
+  . "AND groups.is_public='1' "
+  . "GROUP BY groups.unix_group_name "
+  . "ORDER BY groups.unix_group_name";
 
 $result_without_history = db_query($sql_without_history);
 $rows_without_history = db_numrows($result_without_history);
@@ -245,6 +272,10 @@ if ($rows_without_history != $rows)
   unset($content);
   for ($i=0; $i<$rows; $i++)
     {
+      # Ignore if requesting for inclusion
+      if (db_result($result, $i, 'admin_flags') == 'P')
+	{ continue; }
+
       $content .= '<li class="'.utils_get_alt_row_color($j).'">';
       $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />';
       $date_joined = db_result($result, $i, 'date');
@@ -274,6 +305,51 @@ if ($rows_without_history != $rows)
 
   print $HTML->box_bottom(1);
 
+  # List of squad members, if appliable
+  if ($is_squad)
+    {
+      
+      print "<br />\n";
+      print $HTML->box_top(_("Members"),'',1);
+
+      $sql = "SELECT user.user_name, user.realname, user.user_id FROM user,user_squad "
+	. "WHERE user.user_id=user_squad.user_id "
+	. "AND user_squad.squad_id='".$user_id."' "
+	. "GROUP BY user.user_name ";
+
+      $result = db_query($sql);
+      $rows = db_numrows($result);
+
+      $j = 1;
+      unset($content);
+      for ($i=0; $i<$rows; $i++)
+	{
+
+	  $content .= '<li class="'.utils_get_alt_row_color($j).'">';
+	  $content .= utils_user_link(db_result($result,$i,'user_name'),
+				      db_result($result,$i,'realname'));
+	  $content .= '</li>';
+	  $exists=1;
+	  $j++;
+	}
+      
+      if (!$exists)
+	{
+	  print _("None found");
+	}
+      else
+	{
+	  print '<ul class="boxli">'.$content.'</ul>';
+	}
+
+  unset($exists);
+
+  print $HTML->box_bottom(1);
+
+
+    }
+
+
 
   print html_splitpage(3).'<p class="clearr">&nbsp;</p>';
 
