@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: quitproject.php 5550 2006-08-10 22:28:44Z toddy $
+# $Id: quitproject.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #                          Wallace Lee
@@ -60,7 +60,7 @@ print '<div class="center"><input type="submit" name="confirm" value="'._("Confi
 }
 else
 {
-  db_query("DELETE FROM user_group WHERE user_id='".user_getid()."' AND group_id='$quitting_group_id'");
+  member_remove(user_getid(), sane_all("quitting_group_id"));
   
   # Mail the changes so the admins know what happened
   # unless it is a request for inclusion cancelled
