@@ -2,13 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: submit.php 5551 2006-08-10 22:30:03Z toddy $
+# $Id: submit.php 6431 2006-11-22 10:14:55Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
-#  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -131,7 +129,7 @@ form_input("hidden", "group_id", $group_id).'
                	<span class="preinput">'._("Subject:").'</span><br/>&nbsp;&nbsp;
 		<input type="text" name="summary" value="'.$summary.'" size="65" maxlenght="80" />
 		<br />
-		<span class="preinput">'._("Details:").'</span><br />&nbsp;&nbsp;
+		<span class="preinput">'.sprintf(_("Details %s:"), markup_info("full")).'</span><br />&nbsp;&nbsp;
 		<textarea name="details" rows="20" cols="65" wrap="soft">'.$details.'</textarea><br />'.
 form_footer();
 
