@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Savane.pm 4565 2005-06-30 16:47:39Z toddy $
+# $Id: Savane.pm 5654 2006-09-05 15:57:26Z yeupou $
 #
 # Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -29,11 +29,13 @@ use Term::ANSIColor qw(:constants);
 use DBI;
 use POSIX qw(strftime);
 use File::Basename;
+use Text::Wrap qw(&wrap $columns);
 
 # Load modules
 use Savane::Version;
 use Savane::Conf;
 use Savane::DB;
+use Savane::Locks;
 use Savane::Mail;
 use Savane::User;
 use Savane::Groups;
