@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Cvs.pm 6007 2006-09-28 21:33:26Z beuc $
+# $Id: Cvs.pm 6431 2006-11-22 10:14:55Z yeupou $
 #
-# Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+# Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                         Sylvain Beucler <beuc--beuc.net>
 #                         Free Software Foundation, Inc.
 # 
@@ -132,7 +132,7 @@ LogHistory=AMRT
 	system("mkdir", "$dir_cvs/$name");    # create the default module
 	system("chmod", "2775", "$dir_cvs/$name");
 	system("chgrp", "-R", $name, $dir_cvs);
-	system("chown", "root.adm", "$dir_cvs/CVSROOT", "-R");
+	system("chown", "root:adm", "$dir_cvs/CVSROOT", "-R");
 	                                     # make the CVSROOT ro for anybody
 	                                     # doing otherwise is a major
 	                                     # security hole.
