@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Download.pm 5540 2006-08-10 21:21:50Z toddy $
+# $Id: Download.pm 6431 2006-11-22 10:14:55Z yeupou $
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Sylvain Beucler <beuc--beuc.net>
 #                          Free Software Foundation, Inc.
 # 
@@ -74,7 +74,7 @@ sub DownloadMakeAreaSavannah {
     my $dir_public = "/srv/download/$name";
     mkdir ($dir_public);
     chmod (00755, $dir_public);
-    system('/bin/chown', "gatekpr.$name", $dir_public);
+    system('/bin/chown', "gatekpr:$name", $dir_public);
     system('/bin/chmod', "2775", $dir_public);
 
     # print LOG strftime "[$script] %c ---- created upload $name\n", localtime;
@@ -84,7 +84,7 @@ sub DownloadMakeAreaSavannah {
     my $dir_upload = "$gatekpr_prefix/upload/incoming/savannah/$name";
     mkdir ($dir_upload);
     chmod (00770, $dir_upload);
-    system ('/bin/chown', 'upload.gatekpr', $dir_upload);
+    system ('/bin/chown', 'upload:gatekpr', $dir_upload);
 
     # print LOG strftime "[$script] %c ---- created ftp-in $name\n", localtime;
     # print LOG strftime "[$script] %c ---- created ftp-out $name\n", localtime;
@@ -97,8 +97,8 @@ sub DownloadMakeAreaSavannah {
     mkdir ($dir_ftpout);
     chmod (00770, $dir_ftpin);
     chmod (00770, $dir_ftpout);
-    system ('/bin/chown', 'gatekpr.gatekpr', $dir_ftpin);
-    system ('/bin/chown', 'gatekpr.gatekpr', $dir_ftpout);
+    system ('/bin/chown', 'gatekpr:gatekpr', $dir_ftpin);
+    system ('/bin/chown', 'gatekpr:gatekpr', $dir_ftpout);
 
     return;
 }
