@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Groups.pm 5540 2006-08-10 21:21:50Z toddy $
+# $Id: Groups.pm 6431 2006-11-22 10:14:55Z yeupou $
 #
 # Copyright 2003-20005 (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -33,7 +33,7 @@ use Savane::Util;
 
 # Exports
 our @ISA = qw(Exporter);
-our @EXPORT = qw(GetGroupSettings PrintGroupSettings SetGroupSettings GetGroupList DeleteGroup DeleteGroups GetGroupName GetGroupGPGKeyringFile StoreGroupGPGKeyring GroupAddGPGKey GetGroupTypeHost GetGroupTypeDescription IsGroupHomepageOnCvs IsGroupHomepageDirGuessed CanGroupUseHomepage GetGroupHomepageHost GetGroupHomepageDir GetGroupHomepageCvsModule GetGroupHomepageUrl CanGroupUseCvs GetGroupCvsHost GetGroupCvsDir GetGroupCvsUrl CanGroupUseDownload GetGroupDownloadHost GetGroupDownloadDir GetGroupDownloadUrl CanGroupUseMailinglist GetGroupMailinglistHost GetGroupMailinglistListinfoUrl GetGroupMailinglistArchivesUrl GetGroupMailinglistArchivesPrivateUrl GetGroupMailinglistAdminUrl CanGroupUseForum CanGroupUsePatch CanGroupUseTask CanGroupUseNews CanGroupUseSupport CanGroupUseBug GetGroupUsers PrintGroupUsers GetGroupAdmins PrintGroupAdmins GetGroupAdminsMail PrintGroupAdminsMail GetGroupType PrintGroupType GetGroupTypeSettings PrintGroupTypeSettings GetGroupTypeName );
+our @EXPORT = qw(GetGroupSettings PrintGroupSettings SetGroupSettings GetGroupList DeleteGroup DeleteGroups GetGroupName GetGroupGPGKeyringFile StoreGroupGPGKeyring GroupAddGPGKey GetGroupUsers PrintGroupUsers GetGroupAdmins PrintGroupAdmins GetGroupAdminsMail PrintGroupAdminsMail GetGroupType PrintGroupType GetGroupTypeSettings PrintGroupTypeSettings GetGroupTypeName );
 our $version = 1;
 
 # Imports (needed for strict).
@@ -203,98 +203,6 @@ sub GroupAddGPGKey {
 }
 
 
-## Shortcuts, arg1 is group name
-# (Group within the sub name ? it should be obvious here.
-#  let's avoid implicit...)
-sub GetGroupTypeHost {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'base_host');
-}
-sub GetGroupTypeDescription {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'description');
-}
-sub IsGroupHomepageOnCvs {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'is_homepage_on_cvs');
-}
-sub IsGroupHomepageDirGuessed {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'is_homepage_dir_guessed');
-}
-sub CanGroupUseHomepage {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_homepage');
-}
-sub GetGroupHomepageHost {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'homepage_host');
-}
-sub GetGroupHomepageDir { 
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'homepage_dir').$_[0];
-}
-sub GetGroupHomepageCvsModule {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'homepage_cvs_module_prefix').$_[0];
-}
-sub GetGroupHomepageUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'homepage_cvs_view_url').$_[0];
-}
-sub CanGroupUseCvs {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_download');
-}
-sub GetGroupCvsHost {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'cvs_host');
-}
-sub GetGroupCvsDir { 
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'cvs_dir').$_[0];
-}
-sub GetGroupCvsUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'cvs_view_url').$_[0];
-}
-sub CanGroupUseDownload {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_download');
-}
-sub GetGroupDownloadHost {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'download_host');
-}
-sub GetGroupDownloadDir { 
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'download_dir').$_[0];
-}
-sub GetGroupDownloadUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'download_url').$_[0];
-}
-sub CanGroupUseMailinglist {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_mailing_list');
-}
-sub GetGroupMailinglistHost {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'mailing_list_host');
-}
-sub GetGroupMailinglistListinfoUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'mailing_list_listinfo_url').$_[0];
-}
-sub GetGroupMailinglistArchivesUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'mailing_list_archives_url').$_[0];
-}
-sub GetGroupMailinglistArchivesPrivateUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'mailing_list_archives_private_url').$_[0];
-}
-sub GetGroupMailinglistAdminUrl {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'mailing_list_admin_url').$_[0];
-}
-sub CanGroupUseForum {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_forum');
-}
-sub CanGroupUsePatch {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_patch');
-}
-sub CanGroupUseTask {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_task');
-}
-sub CanGroupUseNews {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_news');
-}
-sub CanGroupUseSupport {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_support');
-}
-sub CanGroupUseBug {
-    return GetGroupTypeSettings(GetGroupType($_[0]), 'can_use_bug');
-}
-
-
 ## Get list of group's users
 # arg1 : which group name
 sub GetGroupUsers {
