@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Svn.pm 5540 2006-08-10 21:21:50Z toddy $
+# $Id: Svn.pm 6503 2007-06-04 16:06:15Z rudy $
 #
 # Copyright 2005      (c) Timothee Besset <ttimo--ttimo.net>
 # 
@@ -32,7 +32,7 @@ use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw(SvnMakeArea SvnMakeAreaAttic );
+our @EXPORT = qw(SvnMakeArea SvnMakeAreaAttic SvnMakeAreaAtticWebsite SvnMakeAreaUgent);
 our $version = 1;
 
 sub SvnMakeArea {
@@ -74,10 +74,9 @@ sub SvnMakeArea {
 
 
 
-## Make a svn area at gn!elsewhere.
+## Make a svn area at gna!
 ## Ask yeupou--gna.org before modifying this function
 sub SvnMakeAreaAttic {
-    # Run the default sequence
     my $ret = SvnMakeArea(@_);
     
     if ($ret) {
@@ -85,10 +84,13 @@ sub SvnMakeAreaAttic {
 
 	$dir_svn =~ s/\%PROJECT/$name/;
 	
-	# hardcode svnmailer support
+	# hardcode svnmailer + ciabot support
 	open(FILE, "> $dir_svn/hooks/post-commit");
 	print FILE "#!/usr/bin/perl
+# (obviously, svn-mailer and ciabot.sh must be in the relevant PATH)
+system(\"sv_extra_svn_postcommit_brigde\", \"-t\", \"\$ARGV[0]\", \"-r\", \"\$ARGV[1]\", \"-p\", \"$name\");
 system(\"svn-mailer\", \"-d\$ARGV[0]\", \"-r\$ARGV[1]\", \"-f/etc/svn-mailer.conf\");
+system(\"ciabot.sh\", \"\$ARGV[0]\", \"\$ARGV[1]\", \"$name\");
 ";
 	close(FILE);
 	system("chmod", "755", "$dir_svn/hooks", "$dir_svn/hooks/post-commit");
@@ -97,3 +99,68 @@ system(\"svn-mailer\", \"-d\$ARGV[0]\", \"-r\$ARGV[1]\", \"-f/etc/svn-mailer.con
 
     return;
 }
+
+## Make a svn area at UGent
+## Ask rudy.gevaert--ugent before modifying this function
+sub SvnMakeAreaUgent {
+    my $ret = SvnMakeArea(@_);
+
+    if ($ret) {
+        my ($name,$dir_svn) = @_;
+
+        $dir_svn =~ s/\%PROJECT/$name/;
+
+        # hardcode mail + postcommit brigde
+        open(FILE, "> $dir_svn/hooks/post-commit");
+        print FILE "#!/usr/bin/perl
+system(\"/usr/local/bin/sv_extra_svn_postcommit_brigde\", \"-t\", \"\$ARGV[0]\", \"-r\", \"\$ARGV[1]\", \"-p\", \"$name\") if -e \"/usr/local/bin/sv_extra_svn_postcommit_brigde\";
+system(\"/usr/lib/subversion/hook-scripts/commit-email.pl\", \"\$ARGV[0]\", \"\$ARGV[1]\", \"${name}-commit\\\@savannah.ugent.be\") if -e \"/usr/lib/subversion/hook-scripts/commit-email.pl\";
+";
+        close(FILE);
+        system("chmod", "755", "$dir_svn/hooks", "$dir_svn/hooks/post-commit");
+        return " ".$dir_svn;
+    }
+
+    return;
+}
+
+
+## Make a svn area for the website at gna!
+## Ask yeupou--gna.org before modifying this function
+sub SvnMakeAreaAtticWebsite {
+    # Create the whole repository, if it does not exists yet
+    my ($name,$dir_svn) = @_;
+    $dir_svn =~ s/\%PROJECT/$name/;
+    
+    my $missing = 0;
+
+    unless (-e $dir_svn) {
+	SvnMakeAreaAttic(@_);
+        # if dir svn still does not exists, there is something weird
+	return 0 unless -e $dir_svn;
+	$missing = 1;
+    }
+
+    # Add the subdirectory is not yet present
+
+    # Check if necessary
+    unless ($missing) {
+	# From here, assume that the entry may be missing and that it is not
+	# only if svnlook return on STDOUT the correct string
+	$missing = 1;
+	open(CHECK, "svnlook tree $dir_svn /website |");
+	while (<CHECK>) {
+	    chomp($_);
+	    $missing = 0 if $_ eq "website/";
+	    last;
+	}
+	close(CHECK);
+    }
+
+    if ($missing) {
+	system("svn", "mkdir", "-q", "-m \"website at home.gna.org\"", "file://$dir_svn/website");
+	return " ".$dir_svn;
+    }
+
+    return;
+}
