@@ -2,11 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: User.pm 5540 2006-08-10 21:21:50Z toddy $
+# $Id: User.pm 6515 2009-11-30 10:45:12Z beuc $
 #
 #  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
-#                          Sylvain Beucler <beuc--beuc.net>
 #                          Free Software Foundation, Inc.
+#  Copyright (C) 2005, 2006, 2009  Sylvain Beucler <beuc--beuc.net>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
 ##
 
 use strict "vars";
+use English;
 require Exporter;
 
 use Savane::Util;
@@ -121,6 +122,101 @@ sub GetUserName {
     return $dbd->selectrow_array("SELECT user_name FROM user WHERE user_id='".$_[0]."'");
 }
 
+## Get system uid/gid
+sub GetUserUidGid {
+    my $user = $_[0];
+    my ($name,$passwd,$uid,$gid,
+	$quota,$comment,$gcos,$dir,$shell,$expire) = getpwnam($user);
+    return ($uid,$gid);
+}
+
+## Become this effective user (EUID/EGID) and perform this action.
+## 
+## This protect against symlink attacks; they are inevitable when
+## working in a directory owned by a local user.  We could naively
+## check for the presence of symlinks, but then we'd still be
+## vulnerable to a symlink race attack.
+## 
+## We'll use set_e_uid/set_e_gid for efficiency and simplicity
+## (e.g. we can get the return value directly), which is enough for
+## opening files and similar basic operations.  When calling external
+## programs, you should use fork&exec&setuid/setgid.
+## 
+# arg1: username
+# arg2: a Perl sub{}
+sub SudoEffectiveUser {
+    my $user = $_[0];
+    my $sub_unprivileged = $_[1];
+
+    my ($uid,$gid) = GetUserUidGid($user);
+    if ($uid eq "" or $gid eq "") {
+	print "Unknown user: $user";
+	return;
+    }
+
+    my $old_GID = $GID; # save additional groups
+    $! = '';
+    $EGID = "$gid $gid"; # set egid and additional groups
+    if ($! ne '') {
+	warn "Cannot setegid($gid $gid): $!";
+	return;
+    }
+    $EUID = $uid;
+    if ($! ne '') {
+	warn "Cannot seteuid($uid): $!";
+	return;
+    }
+
+    # Perform the action under this effective user:
+    my $ret = &$sub_unprivileged();
+
+    # Back to root
+    undef($EUID);     # restore euid==uid
+    $EGID = $old_GID; # restore egid==gid + additional groups
+
+    return $ret;
+}
+
+## Fork, become this user (UID/GID) and run this command. Return a
+## file handle to the child process's pipe.
+## 
+# arg1: username
+# arg2&next: an array (command+params) to pass to exec()
+sub SudoForkPipe {
+    my $user = shift(@_);
+    my @command_args = @_;
+
+    my ($uid,$gid) = GetUserUidGid($user);
+    if ($uid eq "" or $gid eq "") {
+	print "Unknown user: $user";
+	return;
+    }
+
+    local *INOUT;
+    my $pid = open(*INOUT, "|-");
+
+    if ($pid) {                   # parent
+        return *INOUT;
+    } else {                      # child
+	$! = '';
+	$GID=$EGID="$gid $gid"; # set gid and additional groups
+	if ($! ne '') {
+	    warn "Cannot setegid($gid $gid): $!";
+	    exit 1;
+	}
+	$UID=$EUID=$uid;
+	if ($! ne '') {
+	    warn "Cannot seteuid($uid): $!";
+	    exit 1;
+	}
+
+	# Also change the home directory
+	$ENV{'HOME'} = GetUserHome($user);
+
+        exec (@command_args) or exit 1;
+    }
+}
+
 #####
 ##### From the system
 #####
@@ -183,7 +279,7 @@ sub GetUserSSHKeyReal {
 sub DeleteUser {
     # If it exists on the system, delete the account
     if (getpwnam($_[0])) {
-	`userdel -r $_[0]`;
+	system("userdel", "-r", $_[0]);
     }
     # Remove from the database, if arg 2 = 1    
     $dbd->do("DELETE FROM user WHERE user_name='".SQLStringEscape($_[0])."'") if ($_[0] && $_[1]);
@@ -205,9 +301,34 @@ sub PrintAliasesList {
     my $handle = STDOUT;
     $handle = $_[0] if $_[0];
 
-    foreach my $line (GetDB("user", "status='A'", "user_name,email")) {
-	my @line = split(",", $line);
-	print $handle join(": ", map {defined $_ ? $_ : "(null)"} @line), "\n";
+    my %email_by_uid;
+    print $handle "# Users Accounts\n";
+    foreach my $line (GetDBLists("user", "status='A' ORDER BY user_name", "user_name,email,user_id")) {
+	my ($user_name, $email, $user_id) = @$line;
+	next unless $email;
+	print $handle "$user_name: $email\n";
+	$email_by_uid{$user_id} = $email;
+    }
+
+    print $handle "# Squad Accounts\n";
+    foreach my $line (GetDBLists("user", "status='SQD' ORDER BY user_name", "user_name,user_id")) {
+	my ($squad_name, $squad_id) = @$line;
+	my $email;
+	foreach my $user_id (GetDB("user_squad", "squad_id='$squad_id'", "user_id")) {
+	    chomp($user_id);
+
+	    # Get previously found email (if not found, it means
+	    # the squad contains non valid members that we will ignore)
+	    next unless $email_by_uid{$user_id};
+
+	    $email .= ", " if $email;
+	    $email .= $email_by_uid{$user_id};
+	}
+	
+	# skip the squad if it has no members
+	next unless $email;
+
+	print $handle "$squad_name: $email\n";	
     }
 }
 
@@ -224,11 +345,21 @@ sub UserAddSSHKey {
     my $authorized_keys = $_[1];
     my $ssh_keys_registered = 0;
 
-    open(SSH_KEY, "> $home/.ssh/authorized_keys");
-    # In the database, linebreak are ###
-    $ssh_keys_registered = ($authorized_keys =~ s/###/\n/g); #' count keys
-    print SSH_KEY $authorized_keys; 
-    close(SSH_KEY);
+    # If the authorized key entry is NULL, it means that we want to actually
+    # simply remove the SSH file, so we dont even touch the file
+    if ($authorized_keys ne '') {
+	my $authorized_keys_file = "$home/.ssh/authorized_keys";
+	SudoEffectiveUser($user, sub {
+	    if (open(SSH_KEY, "> $authorized_keys_file")) {
+		# In the database, linebreak are ###
+		$ssh_keys_registered = ($authorized_keys =~ s/###/\n/g); #' count keys
+		print SSH_KEY $authorized_keys; 
+		close(SSH_KEY);
+	    } else {
+		warn("Cannot write $authorized_keys_file: " . $!);
+	    }
+	     });
+    }
 
     # Store the information in the database, an interface the frontend could
     # (but does not currently) use to tell the user if all this keys are 
@@ -247,41 +378,37 @@ sub UserAddSSHKey {
 # return the number of keys registered.
 sub UserAddGPGKey {
     my ($user, $key) = @_;
+    return 1 unless ($key);
 
     my $home = GetUserHome($user);
 
-    unlink("$home/.gnupg/pubring.gpg");
-
-    return 1 unless ($key);
+    SudoEffectiveUser($user, sub { mkdir("$home/.gnupg"); });
+    my $pubring_file = "$home/.gnupg/pubring.gpg";
+    SudoEffectiveUser($user, sub { unlink($pubring_file); });
 
     my @gpg_args = ("/usr/bin/gpg",
 		    "--batch",
 		    "--quiet",
 		    "--no-tty",
+		    "--no-options", # disable ~/.gnupg and gpg.conf creation
                     "--no-default-keyring",
                     "--keyring",
-                    "$home/.gnupg/pubring.gpg",
+                    $pubring_file,
                     "--import",
                     "-");
 
-    my $pid = open (GPG, "|-");
-
-    if ($pid) {                   # parent
-        print GPG $key;
-        close (GPG);
-        my $ret = $?;
-        if ($ret) {
-            SetUserSettings($user, "gpg_key_count", 0);
-        } else {
-            SetUserSettings($user, "gpg_key_count", 1);
-        }
-        return $ret;
-    } else {                      # child
-        exec (@gpg_args) || exit 1;
+    my $inout = SudoForkPipe($user, @gpg_args);
+    print $inout $key;
+    close ($inout);
+    my $ret = $?;
+    if ($ret) {
+	SetUserSettings($user, "gpg_key_count", 0);
+    } else {
+	SetUserSettings($user, "gpg_key_count", 1);
     }
-
-    return 1;
+    return $ret;
 }
+
 ## Store ASCII version of the GPG key, for future comparisons
 # arg1 : username
 # arg2 : content
@@ -290,13 +417,16 @@ sub UserStoreGPGKey {
     my ($user, $key) = @_;
     my $home = GetUserHome($user);
 
-    if (!$key or $key eq "NULL") {
-	unlink("$home/.gnupg/ascii-public-key");
-    } else {
-	open(STOREFILE, "> $home/.gnupg/ascii-public-key");
-	print STOREFILE $key;
-	close(STOREFILE);
-    }
+    SudoEffectiveUser($user, sub { mkdir("$home/.gnupg"); });
+    SudoEffectiveUser($user, sub {
+	if (!$key or $key eq "NULL") {
+	    unlink("$home/.gnupg/ascii-public-key");
+	} else {
+	    open(STOREFILE, "> $home/.gnupg/ascii-public-key");
+	    print STOREFILE $key;
+	    close(STOREFILE);
+	}
+		      });
     return 1;
 }
 
