@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Version.pm 6038 2006-10-03 07:28:33Z yeupou $
+# $Id: Version.pm 6487 2006-12-04 16:39:32Z yeupou $
 #
 # Copyright 2003-2004 (c) Mathieu Roy <yeupou--gnu.org>
 # 
@@ -35,7 +35,7 @@ sub GetVersion {
     # Should be a valid release number or
     #     SVN (toward x.x)
     #     x.x (prerelease)
-    return "2.0";
+    return "SVN (toward 3.1)";
 }
 
 # EOF
